@@ -134,7 +134,7 @@ if __name__ == '__main__':
                          'reference', 'projections.rst')
     table = open(fname, 'w')
 
-    notes = """
+    header = """
         .. (comment): DO NOT EDIT this file.
         .. It is auto-generated by running : cartopy/docs/make_projection.py
         .. Please adjust by making changes there.
@@ -142,8 +142,13 @@ if __name__ == '__main__':
 
         .. _cartopy_projections:
 
+        Cartopy projection list
+        =======================
+
+
         """
-    table.write(textwrap.dedent(notes))
+
+    table.write(textwrap.dedent(header))
 
     def prj_class_sorter(cls):
         return (PRJ_SORT_ORDER.get(cls.__name__, 100),
