@@ -1,19 +1,8 @@
-# (C) British Crown Copyright 2011 - 2020, Met Office
+# Copyright Cartopy Contributors
 #
-# This file is part of cartopy.
-#
-# cartopy is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the
-# Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# cartopy is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with cartopy.  If not, see <https://www.gnu.org/licenses/>.
+# This file is part of Cartopy and is released under the LGPL license.
+# See COPYING and COPYING.LESSER in the root of the repository for full
+# licensing details.
 
 """
 Implements image tile identification and fetching from various sources.
@@ -24,36 +13,41 @@ The Matplotlib interface can make use of tile objects (defined below) via the
 :class:`MapQuest Open Aerial tileset <MapQuestOpenAerial>` to an existing axes
 at zoom level 2, do ``ax.add_image(MapQuestOpenAerial(), 2)``. An example of
 using tiles in this way can be found at the
-:ref:`sphx_glr_gallery_eyja_volcano.py` example.
+:ref:`sphx_glr_gallery_scalar_data_eyja_volcano.py` example.
 
 """
 
-from __future__ import (absolute_import, division, print_function)
-
 from abc import ABCMeta, abstractmethod
 import concurrent.futures
+import io
+import os
 import warnings
 
 from PIL import Image
 import shapely.geometry as sgeom
 import numpy as np
-import six
 
 import cartopy
 import cartopy.crs as ccrs
 
 
-class GoogleWTS(six.with_metaclass(ABCMeta, object)):
+class GoogleWTS(metaclass=ABCMeta):
     """
     Implement web tile retrieval using the Google WTS coordinate system.
 
     A "tile" in this class refers to the coordinates (x, y, z).
 
+    The tiles can be saved to a cache directory using the cache parameter, so
+    they are downloaded only once. If it is set to True, the default path
+    stored in the cartopy.config dictionary is used. If it is set to a custom
+    path, this path is used instead of the default one. If it is set to False
+    (the default behavior), the tiles are downloaded each time.
+
     """
     _MAX_THREADS = 24
 
     def __init__(self, desired_tile_form='RGB',
-                 user_agent='CartoPy/' + cartopy.__version__):
+                 user_agent=f'CartoPy/{cartopy.__version__}', cache=False):
         self.imgs = []
         self.crs = ccrs.Mercator.GOOGLE
         self.desired_tile_form = desired_tile_form
@@ -62,13 +56,25 @@ class GoogleWTS(six.with_metaclass(ABCMeta, object)):
         # osm may reject requests if there are too many of them, in which case
         # a change of user_agent may fix the issue.
 
+        # Enable a cache mechanism when cache is equal to True or to a path.
+        self._default_cache = False
+        if cache is True:
+            self._default_cache = True
+            self.cache_path = cartopy.config["cache_dir"]
+        elif cache is False:
+            self.cache_path = None
+        else:
+            self.cache_path = cache
+        self.cache = set({})
+        self._load_cache()
+
     def image_for_domain(self, target_domain, target_z):
         tiles = []
 
         def fetch_tile(tile):
             try:
                 img, extent, origin = self.get_image(tile)
-            except IOError:
+            except OSError:
                 # Some services 404 for tiles that aren't supposed to be
                 # there (e.g. out of range).
                 raise
@@ -86,12 +92,32 @@ class GoogleWTS(six.with_metaclass(ABCMeta, object)):
                 try:
                     img, x, y, origin = future.result()
                     tiles.append([img, x, y, origin])
-                except IOError:
+                except OSError:
                     pass
 
         img, extent, origin = _merge_tiles(tiles)
         return img, extent, origin
 
+    @property
+    def _cache_dir(self):
+        """Return the name of the cache directory"""
+        return os.path.join(
+            self.cache_path,
+            self.__class__.__name__
+        )
+
+    def _load_cache(self):
+        """Load the cache"""
+        if self.cache_path is not None:
+            cache_dir = self._cache_dir
+            if not os.path.exists(cache_dir):
+                os.makedirs(cache_dir)
+                if self._default_cache:
+                    warnings.warn(
+                        'Cartopy created the following directory to cache '
+                        f'GoogleWTS tiles: {cache_dir}')
+            self.cache = self.cache.union(set(os.listdir(cache_dir)))
+
     def _find_images(self, target_domain, target_z, start_tile=(0, 0, 0)):
         """Target domain is a shapely polygon in native coordinates."""
 
@@ -107,9 +133,8 @@ class GoogleWTS(six.with_metaclass(ABCMeta, object)):
                 yield start_tile
             else:
                 for tile in self._subtiles(start_tile):
-                    for result in self._find_images(target_domain, target_z,
-                                                    start_tile=tile):
-                        yield result
+                    yield from self._find_images(target_domain, target_z,
+                                                 start_tile=tile)
 
     find_images = _find_images
 
@@ -145,10 +170,10 @@ class GoogleWTS(six.with_metaclass(ABCMeta, object)):
 
         """
         n = 2 ** z
-        assert 0 <= x <= (n - 1), ("Tile's x index is out of range. Upper "
-                                   "limit %s. Got %s" % (n, x))
-        assert 0 <= y <= (n - 1), ("Tile's y index is out of range. Upper "
-                                   "limit %s. Got %s" % (n, y))
+        assert 0 <= x <= (n - 1), \
+            f"Tile's x index is out of range. Upper limit {n}. Got {x}"
+        assert 0 <= y <= (n - 1), \
+            f"Tile's y index is out of range. Upper limit {n}. Got {y}"
 
         x0, x1 = self.crs.x_limits
         y0, y1 = self.crs.y_limits
@@ -180,32 +205,47 @@ class GoogleWTS(six.with_metaclass(ABCMeta, object)):
         pass
 
     def get_image(self, tile):
-        if six.PY3:
-            from urllib.request import urlopen, Request, HTTPError, URLError
+        from urllib.request import urlopen, Request, HTTPError, URLError
+
+        if self.cache_path is not None:
+            filename = "_".join([str(i) for i in tile]) + ".npy"
+            cached_file = os.path.join(
+                self._cache_dir,
+                filename
+            )
         else:
-            from urllib2 import urlopen, Request, HTTPError, URLError
+            filename = None
+            cached_file = None
 
-        url = self._image_url(tile)
-        try:
-            request = Request(url, headers={"User-Agent": self.user_agent})
-            fh = urlopen(request)
-            im_data = six.BytesIO(fh.read())
-            fh.close()
-            img = Image.open(im_data)
+        if filename in self.cache:
+            img = np.load(cached_file, allow_pickle=False)
+        else:
+            url = self._image_url(tile)
+            try:
+                request = Request(url, headers={"User-Agent": self.user_agent})
+                fh = urlopen(request)
+                im_data = io.BytesIO(fh.read())
+                fh.close()
+                img = Image.open(im_data)
 
-        except (HTTPError, URLError) as err:
-            print(err)
-            img = Image.fromarray(np.full((256, 256, 3), (250, 250, 250),
-                                          dtype=np.uint8))
+            except (HTTPError, URLError) as err:
+                print(err)
+                img = Image.fromarray(np.full((256, 256, 3), (250, 250, 250),
+                                              dtype=np.uint8))
+
+            img = img.convert(self.desired_tile_form)
+            if self.cache_path is not None:
+                np.save(cached_file, img, allow_pickle=False)
+                self.cache.add(filename)
 
-        img = img.convert(self.desired_tile_form)
         return img, self.tileextent(tile), 'lower'
 
 
 class GoogleTiles(GoogleWTS):
     def __init__(self, desired_tile_form='RGB', style="street",
                  url=('https://mts0.google.com/vt/lyrs={style}'
-                      '@177000000&hl=en&src=api&x={x}&y={y}&z={z}&s=G')):
+                      '@177000000&hl=en&src=api&x={x}&y={y}&z={z}&s=G'),
+                 cache=False):
         """
         Parameters
         ----------
@@ -224,9 +264,8 @@ World_Shaded_Relief/MapServer/tile/{z}/{y}/{x}.jpg'``
         style = style.lower()
         self.url = url
         if style not in styles:
-            msg = "Invalid style '%s'. Valid styles: %s" % \
-                (style, ", ".join(styles))
-            raise ValueError(msg)
+            raise ValueError(
+                f"Invalid style {style!r}. Valid styles: {', '.join(styles)}")
         self.style = style
 
         # The 'satellite' and 'terrain' styles require pillow with a jpeg
@@ -234,10 +273,11 @@ World_Shaded_Relief/MapServer/tile/{z}/{y}/{x}.jpg'``
         if self.style in ["satellite", "terrain"] and \
                 not hasattr(Image.core, "jpeg_decoder") or \
                 not Image.core.jpeg_decoder:
-            msg = "The '%s' style requires pillow with jpeg decoding support."
-            raise ValueError(msg % self.style)
-        return super(GoogleTiles, self).__init__(
-            desired_tile_form=desired_tile_form)
+            raise ValueError(
+                f"The {self.style!r} style requires pillow with jpeg decoding "
+                "support.")
+        return super().__init__(desired_tile_form=desired_tile_form,
+                                cache=cache)
 
     def _image_url(self, tile):
         style_dict = {
@@ -260,13 +300,12 @@ class MapQuestOSM(GoogleWTS):
     # this now requires a sign up to a plan
     def _image_url(self, tile):
         x, y, z = tile
-        url = 'https://otile1.mqcdn.com/tiles/1.0.0/osm/%s/%s/%s.jpg' % (
-            z, x, y)
+        url = f'https://otile1.mqcdn.com/tiles/1.0.0/osm/{z}/{x}/{y}.jpg'
         mqdevurl = ('https://devblog.mapquest.com/2016/06/15/'
                     'modernization-of-mapquest-results-in-changes'
                     '-to-open-tile-access/')
-        warnings.warn('{} will require a log in and and will likely'
-                      ' fail. see {} for more details.'.format(url, mqdevurl))
+        warnings.warn(f'{url} will require a log in and and will likely'
+                      f' fail. see {mqdevurl} for more details.')
         return url
 
 
@@ -277,9 +316,7 @@ class MapQuestOpenAerial(GoogleWTS):
     #  Farm Service Agency"
     def _image_url(self, tile):
         x, y, z = tile
-        url = 'https://oatile1.mqcdn.com/tiles/1.0.0/sat/%s/%s/%s.jpg' % (
-            z, x, y)
-        return url
+        return f'https://oatile1.mqcdn.com/tiles/1.0.0/sat/{z}/{x}/{y}.jpg'
 
 
 class OSM(GoogleWTS):
@@ -287,8 +324,7 @@ class OSM(GoogleWTS):
 
     def _image_url(self, tile):
         x, y, z = tile
-        url = 'https://a.tile.openstreetmap.org/%s/%s/%s.png' % (z, x, y)
-        return url
+        return f'https://a.tile.openstreetmap.org/{z}/{x}/{y}.png'
 
 
 class Stamen(GoogleWTS):
@@ -310,31 +346,6 @@ class Stamen(GoogleWTS):
     Please see the attribution notice at http://maps.stamen.com on how to
     attribute this imagery.
 
-    """
-    def __init__(self, style='toner', desired_tile_form='RGB'):
-        super(Stamen, self).__init__(desired_tile_form=desired_tile_form)
-        self.style = style
-
-    def _image_url(self, tile):
-        return ('http://tile.stamen.com/{self.style}/{z}/{x}/{y}.png'
-                .format(self=self, x=tile[0], y=tile[1], z=tile[2]))
-
-
-class StamenTerrain(Stamen):
-    """
-    **DEPRECATED:** This class is deprecated. Please use
-    ``Stamen('terrain-background')`` instead.
-
-    Terrain tiles defined for the continental United States, and include land
-    color and shaded hills. The land colors are a custom palette developed by
-    Gem Spear for the National Atlas 1km land cover data set, which defines
-    twenty-four land classifications including five kinds of forest,
-    combinations of shrubs, grasses and crops, and a few tundras and wetlands.
-    The colors are at their highest contrast when fully zoomed-out to the
-    whole U.S., and they slowly fade out to pale off-white as you zoom in to
-    leave room for foreground data and break up the weirdness of large areas
-    of flat, dark green.
-
     References
     ----------
 
@@ -343,19 +354,17 @@ class StamenTerrain(Stamen):
      * https://wiki.openstreetmap.org/wiki/List_of_OSM_based_Services
      * https://github.com/migurski/DEM-Tools
 
-
     """
-    def __init__(self):
-        warnings.warn(
-            "The StamenTerrain class was deprecated in v0.17. "
-            "Please use Stamen('terrain-background') instead.",
-            DeprecationWarning,
-            stacklevel=2)
 
-        # NOTE: This subclass of Stamen exists for legacy reasons.
-        # No further Stamen subclasses will be accepted as
-        # they can easily be created in user code with Stamen(style_name).
-        return super(StamenTerrain, self).__init__(style='terrain-background')
+    def __init__(self, style='toner',
+                 desired_tile_form='RGB', cache=False):
+        super().__init__(desired_tile_form=desired_tile_form,
+                         cache=cache)
+        self.style = style
+
+    def _image_url(self, tile):
+        x, y, z = tile
+        return f'http://tile.stamen.com/{self.style}/{z}/{x}/{y}.png'
 
 
 class MapboxTiles(GoogleWTS):
@@ -365,7 +374,8 @@ class MapboxTiles(GoogleWTS):
     For terms of service, see https://www.mapbox.com/tos/.
 
     """
-    def __init__(self, access_token, map_id):
+
+    def __init__(self, access_token, map_id, cache=False):
         """
         Set up a new Mapbox tiles instance.
 
@@ -374,24 +384,29 @@ class MapboxTiles(GoogleWTS):
 
         Parameters
         ----------
-        access_token
+        access_token : str
             A valid Mapbox API access token.
-        map_id
+        map_id : str
             An ID for a publicly accessible map (provided by Mapbox).
-            This is the map whose tiles will be retrieved through this process.
+            This is the map whose tiles will be retrieved through this process
+            and is specified through the Mapbox Styles API
+            (https://docs.mapbox.com/api/maps/styles/)
 
+            Examples::
+
+                map_id='streets-v11'
+                map_id='outdoors-v11'
+                map_id='satellite-v9'
         """
         self.access_token = access_token
         self.map_id = map_id
-        super(MapboxTiles, self).__init__()
+        super().__init__(cache=cache)
 
     def _image_url(self, tile):
         x, y, z = tile
-        url = ('https://api.mapbox.com/v4/mapbox.{id}/{z}/{x}/{y}.png'
-               '?access_token={token}'.format(z=z, y=y, x=x,
-                                              id=self.map_id,
-                                              token=self.access_token))
-        return url
+
+        return (f'https://api.mapbox.com/styles/v1/mapbox/{self.map_id}/tiles'
+                f'/{z}/{x}/{y}?access_token={self.access_token}')
 
 
 class MapboxStyleTiles(GoogleWTS):
@@ -403,7 +418,8 @@ class MapboxStyleTiles(GoogleWTS):
     For terms of service, see https://www.mapbox.com/tos/.
 
     """
-    def __init__(self, access_token, username, map_id):
+
+    def __init__(self, access_token, username, map_id, cache=False):
         """
         Set up a new instance to retrieve tiles from a Mapbox style.
 
@@ -426,17 +442,13 @@ class MapboxStyleTiles(GoogleWTS):
         self.access_token = access_token
         self.username = username
         self.map_id = map_id
-        super(MapboxStyleTiles, self).__init__()
+        super().__init__(cache=cache)
 
     def _image_url(self, tile):
         x, y, z = tile
-        url = ('https://api.mapbox.com/styles/v1/'
-               '{user}/{mapid}/tiles/256/{z}/{x}/{y}'
-               '?access_token={token}'.format(z=z, y=y, x=x,
-                                              user=self.username,
-                                              mapid=self.map_id,
-                                              token=self.access_token))
-        return url
+        return (f'https://api.mapbox.com/styles/v1/{self.username}'
+                f'/{self.map_id}/tiles/256/{z}/{x}/{y}'
+                f'?access_token={self.access_token}')
 
 
 class QuadtreeTiles(GoogleWTS):
@@ -448,11 +460,11 @@ class QuadtreeTiles(GoogleWTS):
     where the length of the quatree is the zoom level in Google Tile terms.
 
     """
+
     def _image_url(self, tile):
-        url = ('http://ecn.dynamic.t1.tiles.virtualearth.net/comp/'
-               'CompositionHandler/{tile}?mkt=en-'
-               'gb&it=A,G,L&shading=hill&n=z'.format(tile=tile))
-        return url
+        return ('http://ecn.dynamic.t1.tiles.virtualearth.net/comp/'
+                f'CompositionHandler/{tile}?mkt=en-'
+                'gb&it=A,G,L&shading=hill&n=z')
 
     def tms_to_quadkey(self, tms, google=False):
         quadKey = ""
@@ -474,8 +486,7 @@ class QuadtreeTiles(GoogleWTS):
     def quadkey_to_tms(self, quadkey, google=False):
         # algorithm ported from
         # https://msdn.microsoft.com/en-us/library/bb259689.aspx
-        assert isinstance(quadkey, six.string_types), \
-            'quadkey must be a string'
+        assert isinstance(quadkey, str), 'quadkey must be a string'
 
         x = y = 0
         z = len(quadkey)
@@ -491,8 +502,7 @@ class QuadtreeTiles(GoogleWTS):
                 x |= mask
                 y |= mask
             else:
-                raise ValueError('Invalid QuadKey digit '
-                                 'sequence.' + str(quadkey))
+                raise ValueError(f'Invalid QuadKey digit sequence: {quadkey}')
         # the algorithm works to google tiles, so convert to tms
         if not google:
             y = (2 ** z - 1) - y
@@ -542,7 +552,12 @@ class OrdnanceSurvey(GoogleWTS):
     https://developer.ordnancesurvey.co.uk/os-api-framework-agreement.
     """
     # API Documentation: https://apidocs.os.uk/docs/os-maps-wmts
-    def __init__(self, apikey, layer='Road', desired_tile_form='RGB'):
+
+    def __init__(self,
+                 apikey,
+                 layer='Road',
+                 desired_tile_form='RGB',
+                 cache=False):
         """
         Parameters
         ----------
@@ -558,26 +573,23 @@ class OrdnanceSurvey(GoogleWTS):
         desired_tile_form: optional
             Defaults to 'RGB'.
         """
-        super(OrdnanceSurvey, self).__init__(
-            desired_tile_form=desired_tile_form)
+        super().__init__(desired_tile_form=desired_tile_form,
+                         cache=cache)
         self.apikey = apikey
 
         if layer not in ['Outdoor', 'Road', 'Light', 'Night', 'Leisure']:
-            raise ValueError('Invalid layer {}'.format(layer))
+            raise ValueError(f'Invalid layer {layer}')
 
         self.layer = layer
 
     def _image_url(self, tile):
         x, y, z = tile
-        url = ('https://api2.ordnancesurvey.co.uk/'
-               'mapping_api/v1/service/wmts?'
-               'key={apikey}&height=256&width=256&tilematrixSet=EPSG%3A3857&'
-               'version=1.0.0&style=true&layer={layer}%203857&'
-               'SERVICE=WMTS&REQUEST=GetTile&format=image%2Fpng&'
-               'TileMatrix=EPSG%3A3857%3A{z}&TileRow={y}&TileCol={x}')
-        return url.format(z=z, y=y, x=x,
-                          apikey=self.apikey,
-                          layer=self.layer)
+        return (
+            f'https://api2.ordnancesurvey.co.uk/mapping_api/v1/service/wmts?'
+            f'key={self.apikey}&height=256&width=256&version=1.0.0&'
+            f'tilematrixSet=EPSG%3A3857&style=true&layer={self.layer}%203857&'
+            f'SERVICE=WMTS&REQUEST=GetTile&format=image%2Fpng&'
+            f'TileMatrix=EPSG%3A3857%3A{z}&TileRow={y}&TileCol={x}')
 
 
 def _merge_tiles(tiles):
@@ -634,3 +646,75 @@ def _merge_tiles(tiles):
         img[img_slice] = tile_img
 
     return img, [min(xs), max(xs), min(ys), max(ys)], 'lower'
+
+
+class AzureMapsTiles(GoogleWTS):
+
+    def __init__(self, subscription_key, tileset_id="microsoft.imagery",
+                 api_version="2.0", desired_tile_form='RGB', cache=False):
+        """
+        Set up a new instance to retrieve tiles from Azure Maps.
+
+        Access to Azure Maps REST API requires a subscription key.
+        See https://docs.microsoft.com/en-us/azure/azure-maps/azure-maps-authentication#shared-key-authentication/  # noqa: E501
+        for details.
+
+        Parameters
+        ----------
+        subscription_key
+            A valid Azure Maps subscription key.
+        tileset_id
+            A tileset ID for a map. See
+            https://docs.microsoft.com/en-us/rest/api/maps/renderv2/getmaptilepreview#tilesetid  # noqa: E501
+            for details.
+        api_version
+            API version to use. Defaults to 2.0 as recommended by Microsoft.
+
+        """
+        super().__init__(desired_tile_form=desired_tile_form, cache=cache)
+        self.subscription_key = subscription_key
+        self.tileset_id = tileset_id
+        self.api_version = api_version
+
+    def _image_url(self, tile):
+        x, y, z = tile
+        return (
+            f'https://atlas.microsoft.com/map/tile?'
+            f'api-version={self.api_version}&tilesetId={self.tileset_id}&'
+            f'x={x}&y={y}&zoom={z}&subscription-key={self.subscription_key}')
+
+
+class LINZMapsTiles(GoogleWTS):
+
+    def __init__(self, apikey, layer_id, api_version="v4",
+                 desired_tile_form='RGB', cache=False):
+        """
+        Set up a new instance to retrieve tiles from The LINZ
+        aka. Land Information New Zealand
+
+        Access to LINZ WMTS GetCapabilities requires an API key.
+        Register yourself free in https://id.koordinates.com/signup/
+        to gain access into the LINZ database.
+
+        Parameters
+        ----------
+        apikey
+            A valid LINZ API key specific for every users.
+        layer_id
+            A layer ID for a map. See the "Technical Details" lower down the
+            "About" tab for each layer displayed in the LINZ data service.
+        api_version
+            API version to use. Defaults to v4 for now.
+
+        """
+        super().__init__(desired_tile_form=desired_tile_form, cache=cache)
+        self.apikey = apikey
+        self.layer_id = layer_id
+        self.api_version = api_version
+
+    def _image_url(self, tile):
+        x, y, z = tile
+        return (
+            f'https://tiles-a.koordinates.com/services;'
+            f'key={self.apikey}/tiles/{self.api_version}/'
+            f'layer={self.layer_id}/EPSG:3857/{z}/{x}/{y}.png')
