@@ -399,48 +399,28 @@ class GeoAxes(matplotlib.axes.Axes):
 
         Parameters
         ----------
-        map_projection: optional
-            The target :class:`~cartopy.crs.Projection` of this Axes object.
-
-
-        All other args and keywords are passed through to
-        :class:`matplotlib.axes.Axes`.
-
+        projection : cartopy.crs.Projection
+            The target projection of this Axes.
         """
-        self.projection = kwargs.pop('map_projection')
-        """The :class:`cartopy.crs.Projection` of this GeoAxes."""
+        if "map_projection" in kwargs:
+            warnings.warn("The `map_projection` keyword argument is "
+                          "deprecated, use `projection` to instantiate a "
+                          "GeoAxes instead.")
+            projection = kwargs.pop("map_projection")
+        else:
+            projection = kwargs.pop("projection")
+
+        # The :class:`cartopy.crs.Projection` of this GeoAxes.
+        if not isinstance(projection, ccrs.Projection):
+            raise ValueError("A GeoAxes can only be created with a "
+                             "projection of type cartopy.crs.Projection")
+        self.projection = projection
 
         super().__init__(*args, **kwargs)
         self._gridliners = []
         self.img_factories = []
         self._done_img_factory = False
 
-    @property
-    def outline_patch(self):
-        """
-        DEPRECATED. The patch that provides the line bordering the projection.
-
-        Use GeoAxes.spines['geo'] or default Axes properties instead.
-        """
-        warnings.warn("The outline_patch property is deprecated. Use "
-                      "GeoAxes.spines['geo'] or the default Axes properties "
-                      "instead.",
-                      DeprecationWarning,
-                      stacklevel=2)
-        return self.spines['geo']
-
-    @property
-    def background_patch(self):
-        """
-        DEPRECATED. The patch that provides the filled background of the
-        projection.
-        """
-        warnings.warn('The background_patch property is deprecated. '
-                      'Use GeoAxes.patch instead.',
-                      DeprecationWarning,
-                      stacklevel=2)
-        return self.patch
-
     def add_image(self, factory, *args, **kwargs):
         """
         Add an image "factory" to the Axes.
@@ -485,18 +465,19 @@ class GeoAxes(matplotlib.axes.Axes):
             context manager exits.  Defaults to True.
 
         """
-        data_lim = self.dataLim.frozen().get_points()
-        view_lim = self.viewLim.frozen().get_points()
-        other = (self.ignore_existing_data_limits,
-                 self._autoscaleXon, self._autoscaleYon)
-        try:
-            yield
-        finally:
+        with contextlib.ExitStack() as stack:
             if hold:
-                self.dataLim.set_points(data_lim)
-                self.viewLim.set_points(view_lim)
-                (self.ignore_existing_data_limits,
-                    self._autoscaleXon, self._autoscaleYon) = other
+                stack.callback(self.dataLim.set_points,
+                               self.dataLim.frozen().get_points())
+                stack.callback(self.viewLim.set_points,
+                               self.viewLim.frozen().get_points())
+                stack.callback(setattr, self, 'ignore_existing_data_limits',
+                               self.ignore_existing_data_limits)
+                stack.callback(self.set_autoscalex_on,
+                               self.get_autoscalex_on())
+                stack.callback(self.set_autoscaley_on,
+                               self.get_autoscaley_on())
+            yield
 
     def _draw_preprocess(self, renderer):
         """
@@ -527,8 +508,7 @@ class GeoAxes(matplotlib.axes.Axes):
         # Shared processing steps
         self._draw_preprocess(renderer)
 
-        return matplotlib.axes.Axes.get_tightbbox(
-            self, renderer, *args, **kwargs)
+        return super().get_tightbbox(renderer, *args, **kwargs)
 
     @matplotlib.artist.allow_rasterization
     def draw(self, renderer=None, **kwargs):
@@ -555,10 +535,10 @@ class GeoAxes(matplotlib.axes.Axes):
                             **factory_kwargs)
         self._done_img_factory = True
 
-        return matplotlib.axes.Axes.draw(self, renderer=renderer, **kwargs)
+        return super().draw(renderer=renderer, **kwargs)
 
     def _update_title_position(self, renderer):
-        matplotlib.axes.Axes._update_title_position(self, renderer)
+        super()._update_title_position(renderer)
         if not self._gridliners:
             return
 
@@ -595,9 +575,8 @@ class GeoAxes(matplotlib.axes.Axes):
     def __str__(self):
         return '< GeoAxes: %s >' % self.projection
 
-    def cla(self):
-        """Clear the current axes and adds boundary lines."""
-        result = matplotlib.axes.Axes.cla(self)
+    def __clear(self):
+        """Clear the current axes and add boundary lines."""
         self.xaxis.set_visible(False)
         self.yaxis.set_visible(False)
         # Enable tight autoscaling.
@@ -613,7 +592,18 @@ class GeoAxes(matplotlib.axes.Axes):
         self.dataLim.intervalx = self.projection.x_limits
         self.dataLim.intervaly = self.projection.y_limits
 
-        return result
+    if mpl.__version__ >= '3.6':
+        def clear(self):
+            """Clear the current Axes and add boundary lines."""
+            result = super().clear()
+            self.__clear()
+            return result
+    else:
+        def cla(self):
+            """Clear the current Axes and add boundary lines."""
+            result = super().cla()
+            self.__clear()
+            return result
 
     def format_coord(self, x, y):
         """
@@ -631,7 +621,7 @@ class GeoAxes(matplotlib.axes.Axes):
 
         return (
             f'{x:.4g}, {y:.4g} '
-            f'({abs(lat):f}\u00b0{ns}, {abs(lon):f}\u00b0{ew})'
+            f'({abs(lat):f}°{ns}, {abs(lon):f}°{ew})'
         )
 
     def coastlines(self, resolution='auto', color='black', **kwargs):
@@ -706,47 +696,13 @@ class GeoAxes(matplotlib.axes.Axes):
             raise ValueError('lons and lats must have the same shape.')
 
         for lon, lat in zip(lons, lats):
-            circle = geod.circle(lon, lat, rad_km*1e3, n_samples=n_samples)
+            circle = geod.circle(lon, lat, rad_km * 1e3, n_samples=n_samples)
             geoms.append(sgeom.Polygon(circle))
 
         feature = cartopy.feature.ShapelyFeature(geoms, ccrs.Geodetic(),
                                                  **kwargs)
         return self.add_feature(feature)
 
-    def natural_earth_shp(self, name='land', resolution='110m',
-                          category='physical', **kwargs):
-        """
-        Add the geometries from the specified Natural Earth shapefile to the
-        Axes as a :class:`~matplotlib.collections.PathCollection`.
-
-        Parameters
-        ----------
-        name: optional
-            Name of the shapefile geometry to add.  Defaults to 'land'.
-        resolution: optional
-            Resolution of shapefile geometry to add.  Defaults to '110m'.
-        category: optional
-            Category of shapefile geometry to add.  Defaults to 'physical'.
-
-
-        ``**kwargs`` are passed through to the
-        :class:`~matplotlib.collections.PathCollection` constructor.
-
-        Returns
-        -------
-        The created :class:`~matplotlib.collections.PathCollection`.
-
-        """
-        warnings.warn('This method has been deprecated.'
-                      ' Please use `add_feature` instead.',
-                      DeprecationWarning,
-                      stacklevel=2)
-        kwargs.setdefault('edgecolor', 'face')
-        kwargs.setdefault('facecolor', cartopy.feature.COLORS['land'])
-        feature = cartopy.feature.NaturalEarthFeature(category, name,
-                                                      resolution, **kwargs)
-        return self.add_feature(feature)
-
     def add_feature(self, feature, **kwargs):
         """
         Add the given :class:`~cartopy.feature.Feature` instance to the axes.
@@ -940,14 +896,13 @@ class GeoAxes(matplotlib.axes.Axes):
 
         See :meth:`~matplotlib.axes.Axes.imshow()` for more details.
         """
-        matplotlib.axes.Axes.autoscale_view(self, tight=tight,
-                                            scalex=scalex, scaley=scaley)
+        super().autoscale_view(tight=tight, scalex=scalex, scaley=scaley)
         # Limit the resulting bounds to valid area.
-        if scalex and self._autoscaleXon:
+        if scalex and self.get_autoscalex_on():
             bounds = self.get_xbound()
             self.set_xbound(max(bounds[0], self.projection.x_limits[0]),
                             min(bounds[1], self.projection.x_limits[1]))
-        if scaley and self._autoscaleYon:
+        if scaley and self.get_autoscaley_on():
             bounds = self.get_ybound()
             self.set_ybound(max(bounds[0], self.projection.y_limits[0]),
                             min(bounds[1], self.projection.y_limits[1]))
@@ -1350,7 +1305,7 @@ class GeoAxes(matplotlib.axes.Axes):
 
         if (transform is None or transform == self.transData or
                 same_projection and inside_bounds):
-            result = matplotlib.axes.Axes.imshow(self, img, *args, **kwargs)
+            result = super().imshow(img, *args, **kwargs)
         else:
             extent = kwargs.pop('extent', None)
             img = np.asanyarray(img)
@@ -1394,26 +1349,26 @@ class GeoAxes(matplotlib.axes.Axes):
             kwargs['alpha'] = alpha
 
             # As a workaround to a matplotlib limitation, turn any images
-            # which are RGB(A) with a mask into unmasked RGBA images with alpha
-            # put into the A channel.
+            # which are masked array RGB(A) into RGBA images
+
             if np.ma.is_masked(img) and len(img.shape) > 2:
-                # if we don't pop alpha, imshow will apply (erroneously?) a
-                # 1D alpha to the RGBA array
-                # kwargs['alpha'] is guaranteed to be either 1D, 2D, or None
-                alpha = kwargs.pop('alpha')
-                old_img = img[:, :, 0:3]
-                img = np.zeros(img.shape[:2] + (4, ), dtype=img.dtype)
-                img[:, :, 0:3] = old_img
-                # Put an alpha channel in if the image was masked.
-                if not np.any(alpha):
-                    alpha = 1
-                img[:, :, 3] = np.ma.filled(alpha, fill_value=0) * \
-                    (~np.any(old_img.mask, axis=2))
-                if img.dtype.kind == 'u':
+
+                # transform RGB(A) into RGBA
+                old_img = img
+                img = np.ones(old_img.shape[:2] + (4, ),
+                              dtype=old_img.dtype)
+                img[:, :, :3] = old_img[:, :, :3]
+
+                # if img is RGBA, save alpha channel
+                if old_img.shape[-1] == 4:
+                    img[:, :, 3] = old_img[:, :, 3]
+                elif img.dtype.kind == 'u':
                     img[:, :, 3] *= 255
 
-            result = matplotlib.axes.Axes.imshow(self, img, *args,
-                                                 extent=extent, **kwargs)
+                # apply the mask to the A channel
+                img[np.any(old_img[:, :, :3].mask, axis=2), 3] = 0
+
+            result = super().imshow(img, *args, extent=extent, **kwargs)
 
         return result
 
@@ -1578,10 +1533,9 @@ class GeoAxes(matplotlib.axes.Axes):
     def _gen_axes_spines(self, locations=None, offset=0.0, units='inches'):
         # generate some axes spines, as some Axes super class machinery
         # requires them. Just make them invisible
-        spines = matplotlib.axes.Axes._gen_axes_spines(self,
-                                                       locations=locations,
-                                                       offset=offset,
-                                                       units=units)
+        spines = super()._gen_axes_spines(locations=locations,
+                                          offset=offset,
+                                          units=units)
         for spine in spines.values():
             spine.set_visible(False)
 
@@ -1609,7 +1563,7 @@ class GeoAxes(matplotlib.axes.Axes):
         self.callbacks.connect('xlim_changed', _trigger_patch_reclip)
         self.callbacks.connect('ylim_changed', _trigger_patch_reclip)
 
-    def set_boundary(self, path, transform=None, use_as_clip_path=None):
+    def set_boundary(self, path, transform=None):
         """
         Given a path, update :data:`.spines['geo']` and :data:`.patch`.
 
@@ -1624,12 +1578,6 @@ class GeoAxes(matplotlib.axes.Axes):
             axes' projection.
 
         """
-        if use_as_clip_path is not None:
-            warnings.warn(
-                'Passing use_as_clip_path to set_boundary is deprecated.',
-                DeprecationWarning,
-                stacklevel=2)
-
         if transform is None:
             transform = self.transData
 
@@ -1663,7 +1611,7 @@ class GeoAxes(matplotlib.axes.Axes):
             The default is False, to compute the contours in data-space.
 
         """
-        result = matplotlib.axes.Axes.contour(self, *args, **kwargs)
+        result = super().contour(*args, **kwargs)
 
         # We need to compute the dataLim correctly for contours.
         bboxes = [col.get_datalim(self.transData)
@@ -1711,7 +1659,7 @@ class GeoAxes(matplotlib.axes.Axes):
                     if not hasattr(sub_trans, 'force_path_ccw'):
                         sub_trans.force_path_ccw = True
 
-        result = matplotlib.axes.Axes.contourf(self, *args, **kwargs)
+        result = super().contourf(*args, **kwargs)
 
         # We need to compute the dataLim correctly for contours.
         bboxes = [col.get_datalim(self.transData)
@@ -1749,7 +1697,47 @@ class GeoAxes(matplotlib.axes.Axes):
                              'geodetic, consider using the cyllindrical form '
                              '(PlateCarree or RotatedPole).')
 
-        result = matplotlib.axes.Axes.scatter(self, *args, **kwargs)
+        result = super().scatter(*args, **kwargs)
+        self.autoscale_view()
+        return result
+
+    @_add_transform
+    def annotate(self, text, xy, xytext=None, xycoords='data', textcoords=None,
+                 *args, **kwargs):
+        """
+        Add the "transform" keyword to :func:`~matplotlib.pyplot.annotate`.
+
+        Other Parameters
+        ----------------
+        transform
+            A :class:`~cartopy.crs.Projection`.
+
+        """
+        transform = kwargs.pop('transform', None)
+        is_transform_crs = isinstance(transform, ccrs.CRS)
+
+        # convert CRS to mpl transform for default 'data' setup
+        if is_transform_crs and xycoords == 'data':
+            xycoords = transform._as_mpl_transform(self)
+
+        # textcoords = xycoords by default but complains if xytext is empty
+        if textcoords is None and xytext is not None:
+            textcoords = xycoords
+
+        # use transform if textcoords is data and xytext is provided
+        if is_transform_crs and xytext is not None and textcoords == 'data':
+            textcoords = transform._as_mpl_transform(self)
+
+        # convert to mpl_transform if CRS passed to xycoords
+        if isinstance(xycoords, ccrs.CRS):
+            xycoords = xycoords._as_mpl_transform(self)
+
+        # convert to mpl_transform if CRS passed to textcoords
+        if isinstance(textcoords, ccrs.CRS):
+            textcoords = textcoords._as_mpl_transform(self)
+
+        result = super().annotate(text, xy, xytext, xycoords=xycoords,
+                                  textcoords=textcoords, *args, **kwargs)
         self.autoscale_view()
         return result
 
@@ -1776,7 +1764,7 @@ class GeoAxes(matplotlib.axes.Axes):
         x = pairs[:, 0]
         y = pairs[:, 1]
 
-        result = matplotlib.axes.Axes.hexbin(self, x, y, *args, **kwargs)
+        result = super().hexbin(x, y, *args, **kwargs)
         self.autoscale_view()
         return result
 
@@ -1794,7 +1782,7 @@ class GeoAxes(matplotlib.axes.Axes):
         # Add in an argument checker to handle Matplotlib's potential
         # interpolation when coordinate wraps are involved
         args, kwargs = self._wrap_args(*args, **kwargs)
-        result = matplotlib.axes.Axes.pcolormesh(self, *args, **kwargs)
+        result = super().pcolormesh(*args, **kwargs)
         # Wrap the quadrilaterals if necessary
         result = self._wrap_quadmesh(result, **kwargs)
         # Re-cast the QuadMesh as a GeoQuadMesh to enable future wrapping
@@ -1836,8 +1824,8 @@ class GeoAxes(matplotlib.axes.Axes):
                 dX = np.diff(X, axis=1)
                 # account for the wrap
                 if wrap:
-                    dX = (dX + wrap/2) % wrap - wrap/2
-                dX = dX/2
+                    dX = (dX + wrap / 2) % wrap - wrap / 2
+                dX = dX / 2
                 X = np.hstack((X[:, [0]] - dX[:, [0]],
                                X[:, :-1] + dX,
                                X[:, [-1]] + dX[:, [-1]]))
@@ -2021,7 +2009,7 @@ class GeoAxes(matplotlib.axes.Axes):
             # MPL 3.3 introduced the shading option, and it isn't
             # handled before that for pcolor calls.
             kwargs.pop('shading', None)
-        result = matplotlib.axes.Axes.pcolor(self, *args, **kwargs)
+        result = super().pcolor(*args, **kwargs)
 
         # Update the datalim for this pcolor.
         limits = result.get_datalim(self.transData)
@@ -2103,7 +2091,7 @@ class GeoAxes(matplotlib.axes.Axes):
             if (x.ndim == 1 and y.ndim == 1) and (x.shape != u.shape):
                 x, y = np.meshgrid(x, y)
             u, v = self.projection.transform_vectors(t, x, y, u, v)
-        return matplotlib.axes.Axes.quiver(self, x, y, u, v, *args, **kwargs)
+        return super().quiver(x, y, u, v, *args, **kwargs)
 
     @_add_transform
     def barbs(self, x, y, u, v, *args, **kwargs):
@@ -2178,7 +2166,7 @@ class GeoAxes(matplotlib.axes.Axes):
             if (x.ndim == 1 and y.ndim == 1) and (x.shape != u.shape):
                 x, y = np.meshgrid(x, y)
             u, v = self.projection.transform_vectors(t, x, y, u, v)
-        return matplotlib.axes.Axes.barbs(self, x, y, u, v, *args, **kwargs)
+        return super().barbs(x, y, u, v, *args, **kwargs)
 
     @_add_transform
     def streamplot(self, x, y, u, v, **kwargs):
@@ -2255,7 +2243,7 @@ class GeoAxes(matplotlib.axes.Axes):
             message = 'Warning: converting a masked element to nan.'
             warnings.filterwarnings('ignore', message=message,
                                     category=UserWarning)
-            sp = matplotlib.axes.Axes.streamplot(self, x, y, u, v, **kwargs)
+            sp = super().streamplot(x, y, u, v, **kwargs)
         return sp
 
     def add_wmts(self, wmts, layer_name, wmts_kwargs=None, **kwargs):
