@@ -4,8 +4,6 @@
 # See COPYING and COPYING.LESSER in the root of the repository for full
 # licensing details.
 
-import warnings
-
 import numpy as np
 from numpy.testing import assert_array_equal
 import pytest
@@ -65,10 +63,8 @@ class TestRetrieve:
     def test_srtm_retrieve(self, Source, read_SRTM, max_, min_, pt,
                            download_to_temp):  # noqa: F811
         # test that the download mechanism for SRTM works
-        with warnings.catch_warnings(record=True) as w:
+        with pytest.warns(cartopy.io.DownloadWarning):
             r = Source().srtm_fname(-4, 50)
-            assert len(w) == 1
-            assert issubclass(w[0].category, cartopy.io.DownloadWarning)
 
         assert r.startswith(str(download_to_temp)), \
             'File not downloaded to tmp dir'
