@@ -5,33 +5,14 @@
 # licensing details.
 
 import matplotlib.pyplot as plt
-from packaging.version import parse as parse_version
 import pytest
 
 import cartopy.crs as ccrs
-from cartopy.tests.mpl import MPL_VERSION, ImageTesting
-
-
-class ExampleImageTesting(ImageTesting):
-    """Subclasses ImageTesting to nullify the plt.show commands."""
-    def __call__(self, test_func):
-        fn = ImageTesting.__call__(self, test_func)
-
-        def new_fn(*args, **kwargs):
-            try:
-                show = plt.show
-                plt.show = lambda *args, **kwargs: None
-                r = fn(*args, **kwargs)
-            finally:
-                plt.show = show
-            return r
-
-        new_fn.__name__ = fn.__name__
-        return new_fn
+from cartopy.tests.mpl import MPL_VERSION
 
 
 @pytest.mark.natural_earth
-@ExampleImageTesting(['global_map'])
+@pytest.mark.mpl_image_compare(filename='global_map.png')
 def test_global_map():
     fig = plt.figure(figsize=(10, 5))
     ax = fig.add_subplot(1, 1, 1, projection=ccrs.Robinson())
@@ -47,12 +28,14 @@ def test_global_map():
     ax.plot([-0.08, 132], [51.53, 43.17], transform=ccrs.PlateCarree())
     ax.plot([-0.08, 132], [51.53, 43.17], transform=ccrs.Geodetic())
 
+    return fig
+
 
 @pytest.mark.natural_earth
-@ExampleImageTesting(['contour_label'],
-                     tolerance=(9.9
-                                if MPL_VERSION < parse_version("3.2")
-                                else 0.5))
+@pytest.mark.mpl_image_compare(filename='contour_label.png',
+                               tolerance=(9.9
+                                          if MPL_VERSION.release[:2] < (3, 3)
+                                          else 0.5))
 def test_contour_label():
     from cartopy.tests.mpl.test_caching import sample_data
     fig = plt.figure()
@@ -89,3 +72,5 @@ def test_contour_label():
         inline=True,  # Cut the line where the label will be placed.
         fmt=' {:.0f} '.format,  # Labes as integers, with some extra space.
     )
+
+    return fig
