@@ -11,12 +11,10 @@ import cartopy.crs as ccrs
 import cartopy.feature as cfeature
 from cartopy.io.ogc_clients import _OWSLIB_AVAILABLE
 
-from cartopy.tests.mpl import ImageTesting
-
 
 @pytest.mark.filterwarnings("ignore:Downloading")
 @pytest.mark.natural_earth
-@ImageTesting(['natural_earth'], tolerance=0.97)
+@pytest.mark.mpl_image_compare(filename='natural_earth.png')
 def test_natural_earth():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.add_feature(cfeature.LAND)
@@ -27,11 +25,12 @@ def test_natural_earth():
     ax.add_feature(cfeature.RIVERS)
     ax.set_xlim((-20, 60))
     ax.set_ylim((-40, 40))
+    return ax.figure
 
 
 @pytest.mark.filterwarnings("ignore:Downloading")
 @pytest.mark.natural_earth
-@ImageTesting(['natural_earth_custom'])
+@pytest.mark.mpl_image_compare(filename='natural_earth_custom.png')
 def test_natural_earth_custom():
     ax = plt.axes(projection=ccrs.PlateCarree())
     feature = cfeature.NaturalEarthFeature('physical', 'coastline', '50m',
@@ -40,9 +39,10 @@ def test_natural_earth_custom():
     ax.add_feature(feature)
     ax.set_xlim((-26, -12))
     ax.set_ylim((58, 72))
+    return ax.figure
 
 
-@ImageTesting(['gshhs_coastlines'], tolerance=0.95)
+@pytest.mark.mpl_image_compare(filename='gshhs_coastlines.png', tolerance=0.95)
 def test_gshhs():
     ax = plt.axes(projection=ccrs.Mollweide())
     ax.set_extent([138, 142, 32, 42], ccrs.Geodetic())
@@ -53,11 +53,12 @@ def test_gshhs():
     # Draw higher resolution lakes (and test overriding of kwargs)
     ax.add_feature(cfeature.GSHHSFeature('low', levels=[2],
                                          facecolor='green'), facecolor='blue')
+    return ax.figure
 
 
 @pytest.mark.network
 @pytest.mark.skipif(not _OWSLIB_AVAILABLE, reason='OWSLib is unavailable.')
-@ImageTesting(['wfs'])
+@pytest.mark.mpl_image_compare(filename='wfs.png')
 def test_wfs():
     ax = plt.axes(projection=ccrs.OSGB(approx=True))
     url = 'https://nsidc.org/cgi-bin/atlas_south?service=WFS'
@@ -65,3 +66,4 @@ def test_wfs():
     feature = cfeature.WFSFeature(url, typename,
                                   edgecolor='red')
     ax.add_feature(feature)
+    return ax.figure
