@@ -17,7 +17,6 @@ from cartopy.mpl.gridliner import (
     LATITUDE_FORMATTER, LONGITUDE_FORMATTER,
     classic_locator, classic_formatter)
 
-from cartopy.tests.mpl import ImageTesting
 
 TEST_PROJS = [
     ccrs.PlateCarree,
@@ -32,84 +31,84 @@ TEST_PROJS = [
     ccrs.Robinson,
     ccrs.Sinusoidal,
     ccrs.Stereographic,
-    (ccrs.InterruptedGoodeHomolosine, dict(emphasis='land')),
-    (ccrs.RotatedPole,
-     dict(pole_longitude=180.0,
-          pole_latitude=36.0,
-          central_rotated_longitude=-106.0,
-          globe=ccrs.Globe(semimajor_axis=6370000,
-                           semiminor_axis=6370000))),
-    (ccrs.OSGB, dict(approx=False)),
+    pytest.param((ccrs.InterruptedGoodeHomolosine, dict(emphasis='land')),
+                 id='InterruptedGoodeHomolosine'),
+    pytest.param(
+        (ccrs.RotatedPole,
+         dict(pole_longitude=180.0, pole_latitude=36.0,
+              central_rotated_longitude=-106.0)),
+        id='RotatedPole'),
+    pytest.param((ccrs.OSGB, dict(approx=False)), id='OSGB'),
     ccrs.EuroPP,
     ccrs.Geostationary,
     ccrs.NearsidePerspective,
     ccrs.Gnomonic,
     ccrs.LambertAzimuthalEqualArea,
     ccrs.NorthPolarStereo,
-    (ccrs.OSNI, dict(approx=False)),
+    pytest.param((ccrs.OSNI, dict(approx=False)), id='OSNI'),
     ccrs.SouthPolarStereo,
 ]
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['gridliner1'],
-              # Robinson projection is slightly better in Proj 6+.
-              tolerance=0.7)
+# Robinson projection is slightly better in Proj 6+.
+@pytest.mark.mpl_image_compare(filename='gridliner1.png', tolerance=0.7)
 def test_gridliner():
     ny, nx = 2, 4
 
-    plt.figure(figsize=(10, 10))
+    fig = plt.figure(figsize=(10, 10))
 
-    ax = plt.subplot(nx, ny, 1, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(nx, ny, 1, projection=ccrs.PlateCarree())
     ax.set_global()
     ax.coastlines(resolution="110m")
     ax.gridlines(linestyle=':')
 
-    ax = plt.subplot(nx, ny, 2, projection=ccrs.OSGB(approx=False))
+    ax = fig.add_subplot(nx, ny, 2, projection=ccrs.OSGB(approx=False))
     ax.set_global()
     ax.coastlines(resolution="110m")
     ax.gridlines(linestyle=':')
 
-    ax = plt.subplot(nx, ny, 3, projection=ccrs.OSGB(approx=False))
+    ax = fig.add_subplot(nx, ny, 3, projection=ccrs.OSGB(approx=False))
     ax.set_global()
     ax.coastlines(resolution="110m")
     ax.gridlines(ccrs.PlateCarree(), color='blue', linestyle='-')
     ax.gridlines(ccrs.OSGB(approx=False), linestyle=':')
 
-    ax = plt.subplot(nx, ny, 4, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(nx, ny, 4, projection=ccrs.PlateCarree())
     ax.set_global()
     ax.coastlines(resolution="110m")
     ax.gridlines(ccrs.NorthPolarStereo(), alpha=0.5,
                  linewidth=1.5, linestyle='-')
 
-    ax = plt.subplot(nx, ny, 5, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(nx, ny, 5, projection=ccrs.PlateCarree())
     ax.set_global()
     ax.coastlines(resolution="110m")
     osgb = ccrs.OSGB(approx=False)
     ax.set_extent(tuple(osgb.x_limits) + tuple(osgb.y_limits), crs=osgb)
     ax.gridlines(osgb, linestyle=':')
 
-    ax = plt.subplot(nx, ny, 6, projection=ccrs.NorthPolarStereo())
+    ax = fig.add_subplot(nx, ny, 6, projection=ccrs.NorthPolarStereo())
     ax.set_global()
     ax.coastlines(resolution="110m")
     ax.gridlines(alpha=0.5, linewidth=1.5, linestyle='-')
 
-    ax = plt.subplot(nx, ny, 7, projection=ccrs.NorthPolarStereo())
+    ax = fig.add_subplot(nx, ny, 7, projection=ccrs.NorthPolarStereo())
     ax.set_global()
     ax.coastlines(resolution="110m")
     osgb = ccrs.OSGB(approx=False)
     ax.set_extent(tuple(osgb.x_limits) + tuple(osgb.y_limits), crs=osgb)
     ax.gridlines(osgb, linestyle=':')
 
-    ax = plt.subplot(nx, ny, 8,
-                     projection=ccrs.Robinson(central_longitude=135))
+    ax = fig.add_subplot(nx, ny, 8,
+                         projection=ccrs.Robinson(central_longitude=135))
     ax.set_global()
     ax.coastlines(resolution="110m")
     ax.gridlines(ccrs.PlateCarree(), alpha=0.5, linewidth=1.5, linestyle='-')
 
     delta = 1.5e-2
-    plt.subplots_adjust(left=0 + delta, right=1 - delta,
+    fig.subplots_adjust(left=0 + delta, right=1 - delta,
                         top=1 - delta, bottom=0 + delta)
+    return fig
 
 
 def test_gridliner_specified_lines():
@@ -126,17 +125,13 @@ def test_gridliner_specified_lines():
 
 # The tolerance on these tests are particularly high because of the high number
 # of text objects. A new testing strategy is needed for this kind of test.
-grid_label_tol = grid_label_inline_tol = grid_label_inline_usa_tol = 3.1
-grid_label_tol += 0.8
-grid_label_inline_tol += 1.6
-grid_label_image = 'gridliner_labels'
-grid_label_inline_image = 'gridliner_labels_inline'
-grid_label_inline_usa_image = 'gridliner_labels_inline_usa'
+grid_label_tol = 3.9
 
 
 @pytest.mark.skipif(geos_version == (3, 9, 0), reason="GEOS intersection bug")
 @pytest.mark.natural_earth
-@ImageTesting([grid_label_image], tolerance=grid_label_tol)
+@pytest.mark.mpl_image_compare(filename='gridliner_labels.png',
+                               tolerance=grid_label_tol)
 def test_grid_labels():
     fig = plt.figure(figsize=(10, 10))
 
@@ -164,7 +159,7 @@ def test_grid_labels():
     gl = ax.gridlines(draw_labels=True)
     gl.xlabel_style = gl.ylabel_style = {'size': 9}
 
-    ax = plt.subplot(3, 2, 4, projection=crs_pc)
+    ax = fig.add_subplot(3, 2, 4, projection=crs_pc)
     ax.coastlines(resolution="110m")
     gl = ax.gridlines(
         crs=crs_pc, linewidth=2, color='gray', alpha=0.5, linestyle=':')
@@ -205,12 +200,15 @@ def test_grid_labels():
     gl.xlabel_style = gl.ylabel_style = {'size': 9}
 
     # Increase margins between plots to stop them bumping into one another.
-    plt.subplots_adjust(wspace=0.25, hspace=0.25)
+    fig.subplots_adjust(wspace=0.25, hspace=0.25)
+
+    return fig
 
 
 @pytest.mark.skipif(geos_version == (3, 9, 0), reason="GEOS intersection bug")
 @pytest.mark.natural_earth
-@ImageTesting(['gridliner_labels_tight'], tolerance=4)
+@pytest.mark.mpl_image_compare(filename='gridliner_labels_tight.png',
+                               tolerance=2.92)
 def test_grid_labels_tight():
     # Ensure tight layout accounts for gridlines
     fig = plt.figure(figsize=(7, 5))
@@ -248,68 +246,67 @@ def test_grid_labels_tight():
         for gl in ax._gridliners:
             assert hasattr(gl, '_drawn') and gl._drawn
 
-
-@pytest.mark.skipif(geos_version == (3, 9, 0), reason="GEOS intersection bug")
-@pytest.mark.natural_earth
-@ImageTesting([grid_label_inline_image], tolerance=grid_label_inline_tol)
-def test_grid_labels_inline():
-    plt.figure(figsize=(35, 35))
-    for i, proj in enumerate(TEST_PROJS, 1):
-        if isinstance(proj, tuple):
-            proj, kwargs = proj
-        else:
-            kwargs = {}
-        ax = plt.subplot(7, 4, i, projection=proj(**kwargs))
-        ax.gridlines(draw_labels=True, auto_inline=True)
-        ax.coastlines(resolution="110m")
-        ax.set_title(proj, y=1.075)
-    plt.subplots_adjust(wspace=0.35, hspace=0.35)
+    return fig
 
 
 @pytest.mark.skipif(geos_version == (3, 9, 0), reason="GEOS intersection bug")
 @pytest.mark.natural_earth
-@ImageTesting([grid_label_inline_usa_image],
-              tolerance=grid_label_inline_usa_tol)
-def test_grid_labels_inline_usa():
+@pytest.mark.parametrize('proj', TEST_PROJS)
+@pytest.mark.mpl_image_compare(style='mpl20')
+def test_grid_labels_inline(proj):
+    fig = plt.figure()
+    if isinstance(proj, tuple):
+        proj, kwargs = proj
+    else:
+        kwargs = {}
+    ax = fig.add_subplot(projection=proj(**kwargs))
+    ax.gridlines(draw_labels=True, auto_inline=True)
+    ax.coastlines(resolution="110m")
+    return fig
+
+
+@pytest.mark.skipif(geos_version == (3, 9, 0), reason="GEOS intersection bug")
+@pytest.mark.natural_earth
+@pytest.mark.parametrize('proj', TEST_PROJS)
+@pytest.mark.mpl_image_compare(style='mpl20', tolerance=0.79)
+def test_grid_labels_inline_usa(proj):
     top = 49.3457868  # north lat
     left = -124.7844079  # west long
     right = -66.9513812  # east long
     bottom = 24.7433195  # south lat
-    plt.figure(figsize=(35, 35))
-    for i, proj in enumerate(TEST_PROJS, 1):
-        if isinstance(proj, tuple):
-            proj, kwargs = proj
-        else:
-            kwargs = {}
-        ax = plt.subplot(7, 4, i, projection=proj(**kwargs))
-        try:
-            ax.set_extent([left, right, bottom, top],
-                          crs=ccrs.PlateCarree())
-        except Exception:
-            pass
-        ax.set_title(proj, y=1.075)
-        ax.gridlines(draw_labels=True, auto_inline=True, clip_on=True)
-        ax.coastlines(resolution="110m")
-
-    plt.subplots_adjust(wspace=0.35, hspace=0.35)
+    fig = plt.figure()
+    if isinstance(proj, tuple):
+        proj, kwargs = proj
+    else:
+        kwargs = {}
+    ax = fig.add_subplot(projection=proj(**kwargs))
+    try:
+        ax.set_extent([left, right, bottom, top],
+                      crs=ccrs.PlateCarree())
+    except Exception:
+        pytest.skip('Projection does not support changing extent')
+    ax.gridlines(draw_labels=True, auto_inline=True, clip_on=True)
+    ax.coastlines(resolution="110m")
+    return fig
 
 
 @pytest.mark.skipif(geos_version == (3, 9, 0), reason="GEOS intersection bug")
-@ImageTesting(["gridliner_labels_bbox_style"], tolerance=grid_label_tol)
+@pytest.mark.mpl_image_compare(filename='gridliner_labels_bbox_style.png',
+                               tolerance=grid_label_tol)
 def test_gridliner_labels_bbox_style():
     top = 49.3457868  # north lat
     left = -124.7844079  # west long
     right = -66.9513812  # east long
     bottom = 24.7433195  # south lat
 
-    plt.figure(figsize=(6, 3))
-    ax = plt.subplot(1, 1, 1, projection=ccrs.PlateCarree())
+    fig = plt.figure(figsize=(6, 3))
+    ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
     ax.coastlines(resolution="110m")
     ax.set_extent([left, right, bottom, top],
                   crs=ccrs.PlateCarree())
     gl = ax.gridlines(draw_labels=True)
 
-    bbox_style = {
+    gl.labels_bbox_style = {
         "pad": 0,
         "visible": True,
         "facecolor": "white",
@@ -317,7 +314,7 @@ def test_gridliner_labels_bbox_style():
         "boxstyle": "round, pad=0.2",
     }
 
-    gl.labels_bbox_style = bbox_style
+    return fig
 
 
 @pytest.mark.parametrize(
@@ -343,17 +340,16 @@ def test_gridliner_labels_bbox_style():
     ])
 def test_gridliner_default_fmtloc(
         proj, gcrs, xloc, xfmt, xloc_expected, xfmt_expected):
-    plt.figure()
-    ax = plt.subplot(111, projection=proj)
+    fig = plt.figure()
+    ax = fig.add_subplot(1, 1, 1, projection=proj)
     gl = ax.gridlines(crs=gcrs, draw_labels=False, xlocs=xloc, xformatter=xfmt)
-    plt.close()
     assert isinstance(gl.xlocator, xloc_expected)
     assert isinstance(gl.xformatter, xfmt_expected)
 
 
 def test_gridliner_line_limits():
     fig = plt.figure()
-    ax = plt.subplot(1, 1, 1, projection=ccrs.NorthPolarStereo())
+    ax = fig.add_subplot(1, 1, 1, projection=ccrs.NorthPolarStereo())
     ax.set_global()
     # Test a single value passed in which represents (-lim, lim)
     xlim, ylim = 125, 75
@@ -414,7 +410,7 @@ def test_gridliner_line_limits():
 def test_gridliner_draw_labels_param(draw_labels, result):
     fig = plt.figure()
     lambert_crs = ccrs.LambertConformal(central_longitude=105)
-    ax = plt.axes(projection=lambert_crs)
+    ax = fig.add_subplot(projection=lambert_crs)
     ax.set_extent([75, 130, 18, 54], crs=ccrs.PlateCarree())
     gl = ax.gridlines(draw_labels=draw_labels, rotate_labels=False, dms=True,
                       x_inline=False, y_inline=False)
@@ -423,14 +419,14 @@ def test_gridliner_draw_labels_param(draw_labels, result):
     fig.canvas.draw()
     res = {}
     for loc in 'left', 'right', 'top', 'bottom':
-        artists = getattr(gl, loc+'_label_artists')
+        artists = getattr(gl, f'{loc}_label_artists')
         res[loc] = [a.get_text() for a in artists if a.get_visible()]
     assert res == result
 
 
 def test_gridliner_formatter_kwargs():
     fig = plt.figure()
-    ax = plt.subplot(1, 1, 1, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
     ax.set_extent([-80, -40.0, 10.0, -30.0])
     gl = ax.gridlines(draw_labels=True, dms=False,
                       formatter_kwargs=dict(cardinal_labels={'west': 'O'}))
