@@ -13,7 +13,6 @@ import numpy as np
 import pytest
 
 from cartopy import config
-from cartopy.tests.mpl import ImageTesting
 import cartopy.crs as ccrs
 import cartopy.img_transform as im_trans
 from functools import reduce
@@ -80,7 +79,7 @@ class TestRegrid:
 
 # Bug in latest Matplotlib that we don't consider correct.
 @pytest.mark.natural_earth
-@ImageTesting(['regrid_image'], tolerance=5.55)
+@pytest.mark.mpl_image_compare(filename='regrid_image.png', tolerance=5.55)
 def test_regrid_image():
     # Source data
     fname = os.path.join(config["repo_data_dir"], 'raster', 'natural_earth',
@@ -106,20 +105,21 @@ def test_regrid_image():
                                 target_proj, target_x, target_y)
 
     # Plot
-    plt.figure(figsize=(10, 10))
+    fig = plt.figure(figsize=(10, 10))
     gs = mpl.gridspec.GridSpec(nrows=4, ncols=1,
                                hspace=1.5, wspace=0.5)
     # Set up axes and title
-    ax = plt.subplot(gs[0], projection=target_proj)
-    plt.imshow(new_array, origin='lower', extent=target_extent)
+    ax = fig.add_subplot(gs[0], projection=target_proj)
+    ax.imshow(new_array, origin='lower', extent=target_extent)
     ax.coastlines()
     # Plot each color slice (tests masking)
     cmaps = {'red': 'Reds', 'green': 'Greens', 'blue': 'Blues'}
     for i, color in enumerate(['red', 'green', 'blue']):
-        ax = plt.subplot(gs[i + 1], projection=target_proj)
-        plt.imshow(new_array[:, :, i], extent=target_extent, origin='lower',
-                   cmap=cmaps[color])
+        ax = fig.add_subplot(gs[i + 1], projection=target_proj)
+        ax.imshow(new_array[:, :, i], extent=target_extent, origin='lower',
+                  cmap=cmaps[color])
         ax.coastlines()
 
     # Tighten up layout
-    gs.tight_layout(plt.gcf())
+    gs.tight_layout(fig)
+    return fig
