@@ -5,85 +5,86 @@
 # licensing details.
 
 import re
-import warnings
 
 import numpy as np
 import matplotlib.pyplot as plt
-from packaging.version import parse as parse_version
 import pytest
 
 import cartopy.crs as ccrs
 
-from cartopy.tests.mpl import MPL_VERSION, ImageTesting
+from cartopy.tests.mpl import MPL_VERSION
 
 
-# This is due to a change in MPL 3.5 contour line paths changing
-# ever so slightly.
-contour_tol = 2.25
 @pytest.mark.natural_earth
-@ImageTesting(['global_contour_wrap'], style='mpl20',
-              tolerance=contour_tol)
+@pytest.mark.mpl_image_compare(filename='global_contour_wrap.png',
+                               style='mpl20', tolerance=2.25)
 def test_global_contour_wrap_new_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))
-    plt.contour(x, y, data, transform=ccrs.PlateCarree())
+    ax.contour(x, y, data, transform=ccrs.PlateCarree())
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_contour_wrap'], style='mpl20',
-              tolerance=contour_tol)
+@pytest.mark.mpl_image_compare(filename='global_contour_wrap.png',
+                               style='mpl20', tolerance=2.25)
 def test_global_contour_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))
-    plt.contour(x, y, data)
+    ax.contour(x, y, data)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_contourf_wrap'])
+@pytest.mark.mpl_image_compare(filename='global_contourf_wrap.png')
 def test_global_contourf_wrap_new_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))
-    plt.contourf(x, y, data, transform=ccrs.PlateCarree())
+    ax.contourf(x, y, data, transform=ccrs.PlateCarree())
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_contourf_wrap'])
+@pytest.mark.mpl_image_compare(filename='global_contourf_wrap.png')
 def test_global_contourf_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))
-    plt.contourf(x, y, data)
+    ax.contourf(x, y, data)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_pcolor_wrap'])
+@pytest.mark.mpl_image_compare(filename='global_pcolor_wrap.png')
 def test_global_pcolor_wrap_new_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))[:-1, :-1]
-    plt.pcolor(x, y, data, transform=ccrs.PlateCarree())
+    ax.pcolor(x, y, data, transform=ccrs.PlateCarree())
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_pcolor_wrap'])
+@pytest.mark.mpl_image_compare(filename='global_pcolor_wrap.png')
 def test_global_pcolor_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))[:-1, :-1]
-    plt.pcolor(x, y, data)
+    ax.pcolor(x, y, data)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_scatter_wrap'])
+@pytest.mark.mpl_image_compare(filename='global_scatter_wrap.png')
 def test_global_scatter_wrap_new_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     # By default the coastline feature will be drawn after patches.
@@ -92,146 +93,123 @@ def test_global_scatter_wrap_new_transform():
     ax.coastlines(zorder=0)
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))
-    plt.scatter(x, y, c=data, transform=ccrs.PlateCarree())
+    ax.scatter(x, y, c=data, transform=ccrs.PlateCarree())
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_scatter_wrap'])
+@pytest.mark.mpl_image_compare(filename='global_scatter_wrap.png')
 def test_global_scatter_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines(zorder=0)
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
     data = np.sin(np.sqrt(x ** 2 + y ** 2))
-    plt.scatter(x, y, c=data)
+    ax.scatter(x, y, c=data)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_hexbin_wrap'],
-              tolerance=2 if MPL_VERSION < parse_version('3.2') else 0.5)
+@pytest.mark.mpl_image_compare(filename='global_hexbin_wrap.png')
 def test_global_hexbin_wrap():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines(zorder=2)
     x, y = np.meshgrid(np.arange(-179, 181), np.arange(-90, 91))
     data = np.sin(np.sqrt(x**2 + y**2))
-    plt.hexbin(
+    ax.hexbin(
         x.flatten(),
         y.flatten(),
         C=data.flatten(),
         gridsize=20,
         zorder=1,
     )
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['global_hexbin_wrap'],
-              tolerance=2 if MPL_VERSION < parse_version('3.2') else 0.5)
+@pytest.mark.mpl_image_compare(
+    filename='global_hexbin_wrap.png',
+    tolerance=0.5)
 def test_global_hexbin_wrap_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines(zorder=2)
     x, y = np.meshgrid(np.arange(0, 360), np.arange(-90, 91))
     # wrap values so to match x values from test_global_hexbin_wrap
-    x_wrap = np.where(x >= 180, x-360, x)
+    x_wrap = np.where(x >= 180, x - 360, x)
     data = np.sin(np.sqrt(x_wrap**2 + y**2))
-    plt.hexbin(
+    ax.hexbin(
         x.flatten(),
         y.flatten(),
         C=data.flatten(),
         gridsize=20,
         zorder=1,
     )
-
-
-@ImageTesting(['global_map'],
-              tolerance=0.55)
-def test_global_map():
-    plt.axes(projection=ccrs.Robinson())
-#    ax.coastlines()
-#    ax.gridlines(5)
-
-    plt.plot(-0.08, 51.53, 'o', transform=ccrs.PlateCarree())
-
-    plt.plot([-0.08, 132], [51.53, 43.17], color='red',
-             transform=ccrs.PlateCarree())
-
-    plt.plot([-0.08, 132], [51.53, 43.17], color='blue',
-             transform=ccrs.Geodetic())
+    return ax.figure
 
 
 @pytest.mark.filterwarnings("ignore:Unable to determine extent")
 @pytest.mark.natural_earth
-@ImageTesting(['simple_global'])
+@pytest.mark.mpl_image_compare(filename='simple_global.png')
 def test_simple_global():
-    plt.axes(projection=ccrs.PlateCarree())
-    plt.gca().coastlines()
+    ax = plt.axes(projection=ccrs.PlateCarree())
+    ax.coastlines()
     # produces a global map, despite not having needed to set the limits
+    return ax.figure
 
 
 @pytest.mark.filterwarnings("ignore:Unable to determine extent")
 @pytest.mark.natural_earth
-@ImageTesting(['multiple_projections5'],
-              tolerance=2.05)
-def test_multiple_projections():
-
-    projections = [ccrs.PlateCarree(),
-                   ccrs.Robinson(),
-                   ccrs.RotatedPole(pole_latitude=45, pole_longitude=180),
-                   ccrs.OSGB(approx=True),
-                   ccrs.TransverseMercator(approx=True),
-                   ccrs.Mercator(min_latitude=-85., max_latitude=85.),
-                   ccrs.LambertCylindrical(),
-                   ccrs.Miller(),
-                   ccrs.Gnomonic(),
-                   ccrs.Stereographic(),
-                   ccrs.NorthPolarStereo(),
-                   ccrs.SouthPolarStereo(),
-                   ccrs.Orthographic(),
-                   ccrs.Mollweide(),
-                   ccrs.InterruptedGoodeHomolosine(emphasis='land'),
-                   ccrs.EckertI(),
-                   ccrs.EckertII(),
-                   ccrs.EckertIII(),
-                   ccrs.EckertIV(),
-                   ccrs.EckertV(),
-                   ccrs.EckertVI(),
-                   ]
-
-    rows = np.ceil(len(projections) / 5).astype(int)
-
-    fig = plt.figure(figsize=(10, 2 * rows))
-    for i, prj in enumerate(projections, 1):
-        ax = fig.add_subplot(rows, 5, i, projection=prj)
-
-        ax.set_global()
-
-        ax.coastlines(resolution="110m")
-
-        plt.plot(-0.08, 51.53, 'o', transform=ccrs.PlateCarree())
-        plt.plot([-0.08, 132], [51.53, 43.17], color='red',
-                 transform=ccrs.PlateCarree())
-        plt.plot([-0.08, 132], [51.53, 43.17], color='blue',
-                 transform=prj.as_geodetic())
-
-
-@pytest.mark.natural_earth
-@ImageTesting(['multiple_projections520'], tolerance=0.65)
-def test_multiple_projections_520():
-    # Test projections added in Proj 5.2.0.
+@pytest.mark.parametrize('proj', [
+    ccrs.EckertI,
+    ccrs.EckertII,
+    ccrs.EckertIII,
+    ccrs.EckertIV,
+    ccrs.EckertV,
+    ccrs.EckertVI,
+    ccrs.EqualEarth,
+    ccrs.Gnomonic,
+    pytest.param((ccrs.InterruptedGoodeHomolosine, dict(emphasis='land')),
+                 id='InterruptedGoodeHomolosine'),
+    ccrs.LambertCylindrical,
+    pytest.param((ccrs.Mercator, dict(min_latitude=-85, max_latitude=85)),
+                 id='Mercator'),
+    ccrs.Miller,
+    ccrs.Mollweide,
+    ccrs.NorthPolarStereo,
+    ccrs.Orthographic,
+    pytest.param((ccrs.OSGB, dict(approx=True)), id='OSGB'),
+    ccrs.PlateCarree,
+    ccrs.Robinson,
+    pytest.param((ccrs.RotatedPole,
+                  dict(pole_latitude=45, pole_longitude=180)),
+                 id='RotatedPole'),
+    ccrs.Stereographic,
+    ccrs.SouthPolarStereo,
+    pytest.param((ccrs.TransverseMercator, dict(approx=True)),
+                 id='TransverseMercator'),
+])
+@pytest.mark.mpl_image_compare(
+    tolerance=0.97 if MPL_VERSION.release[:2] < (3, 5) else 0.5,
+    style='mpl20')
+def test_global_map(proj):
+    if isinstance(proj, tuple):
+        proj, kwargs = proj
+    else:
+        kwargs = {}
+    proj = proj(**kwargs)
 
     fig = plt.figure(figsize=(2, 2))
-    ax = fig.add_subplot(1, 1, 1, projection=ccrs.EqualEarth())
-
+    ax = fig.add_subplot(projection=proj)
     ax.set_global()
-
-    ax.coastlines()
+    ax.coastlines(resolution="110m")
 
     ax.plot(-0.08, 51.53, 'o', transform=ccrs.PlateCarree())
-
     ax.plot([-0.08, 132], [51.53, 43.17], color='red',
             transform=ccrs.PlateCarree())
-
     ax.plot([-0.08, 132], [51.53, 43.17], color='blue',
             transform=ccrs.Geodetic())
 
+    return fig
+
 
 def test_cursor_values():
     ax = plt.axes(projection=ccrs.NorthPolarStereo())
@@ -253,32 +231,10 @@ def test_cursor_values():
                      b'\\(22.09[0-9]{4}N, 173.70[0-9]{4}E\\)',
                      r.encode('ascii', 'ignore'))
 
-    plt.close()
-
 
 @pytest.mark.natural_earth
-@ImageTesting(['natural_earth_interface'], tolerance=1.21)
-def test_axes_natural_earth_interface():
-    rob = ccrs.Robinson()
-
-    ax = plt.axes(projection=rob)
-
-    with warnings.catch_warnings(record=True) as all_warnings:
-        warnings.simplefilter('always')
-
-        ax.natural_earth_shp('rivers_lake_centerlines', edgecolor='black',
-                             facecolor='none')
-        ax.natural_earth_shp('lakes', facecolor='blue')
-
-    assert len(all_warnings) == 2
-    for warning in all_warnings:
-        msg = str(warning.message)
-        assert 'deprecated' in msg
-        assert 'add_feature' in msg
-
-
-@pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_global_wrap1'], tolerance=1.27)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_global_wrap1.png',
+                               tolerance=1.27)
 def test_pcolormesh_global_with_wrap1():
     # make up some realistic data with bounds (such as data from the UM)
     nx, ny = 36, 18
@@ -288,19 +244,20 @@ def test_pcolormesh_global_with_wrap1():
     x, y = np.meshgrid(xbnds, ybnds)
     data = np.exp(np.sin(np.deg2rad(x)) + np.cos(np.deg2rad(y)))
     data = data[:-1, :-1]
+    fig = plt.figure()
 
-    ax = plt.subplot(211, projection=ccrs.PlateCarree())
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(2, 1, 1, projection=ccrs.PlateCarree())
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(212, projection=ccrs.PlateCarree(180))
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(2, 1, 2, projection=ccrs.PlateCarree(180))
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
+    return fig
+
 
 def test_pcolormesh_get_array_with_mask():
     # make up some realistic data with bounds (such as data from the UM)
@@ -311,9 +268,10 @@ def test_pcolormesh_get_array_with_mask():
     x, y = np.meshgrid(xbnds, ybnds)
     data = np.exp(np.sin(np.deg2rad(x)) + np.cos(np.deg2rad(y)))
     data = data[:-1, :-1]
+    fig = plt.figure()
 
-    ax = plt.subplot(211, projection=ccrs.PlateCarree())
-    c = plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 1, 1, projection=ccrs.PlateCarree())
+    c = ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree())
     assert c._wrapped_collection_fix is not None, \
         'No pcolormesh wrapping was done when it should have been.'
 
@@ -332,8 +290,8 @@ def test_pcolormesh_get_array_with_mask():
     data = np.exp(np.sin(np.deg2rad(x)) + np.cos(np.deg2rad(y)))
     data2 = data[:-1, :-1]
 
-    ax = plt.subplot(212, projection=ccrs.PlateCarree())
-    c = plt.pcolormesh(xbnds, ybnds, data2, transform=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 1, 2, projection=ccrs.PlateCarree())
+    c = ax.pcolormesh(xbnds, ybnds, data2, transform=ccrs.PlateCarree())
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
@@ -345,7 +303,8 @@ def test_pcolormesh_get_array_with_mask():
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_global_wrap2'], tolerance=1.87)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_global_wrap2.png',
+                               tolerance=1.87)
 def test_pcolormesh_global_with_wrap2():
     # make up some realistic data with bounds (such as data from the UM)
     nx, ny = 36, 18
@@ -359,22 +318,24 @@ def test_pcolormesh_global_with_wrap2():
     x, y = np.meshgrid(xbnds, ybnds)
     data = np.exp(np.sin(np.deg2rad(x)) + np.cos(np.deg2rad(y)))
     data = data[:-1, :-1]
+    fig = plt.figure()
 
-    ax = plt.subplot(211, projection=ccrs.PlateCarree())
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(2, 1, 1, projection=ccrs.PlateCarree())
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(212, projection=ccrs.PlateCarree(180))
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(2, 1, 2, projection=ccrs.PlateCarree(180))
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
+    return fig
+
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_global_wrap3'], tolerance=1.42)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_global_wrap3.png',
+                               tolerance=1.42)
 def test_pcolormesh_global_with_wrap3():
     nx, ny = 33, 17
     xbnds = np.linspace(-1.875, 358.125, nx, endpoint=True)
@@ -391,31 +352,33 @@ def test_pcolormesh_global_with_wrap3():
 
     data = data[:-1, :-1]
     data = np.ma.masked_greater(data, 2.6)
+    fig = plt.figure()
 
-    ax = plt.subplot(311, projection=ccrs.PlateCarree(-45))
-    c = plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                       snap=False)
+    ax = fig.add_subplot(3, 1, 1, projection=ccrs.PlateCarree(-45))
+    c = ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
+                      snap=False)
     assert c._wrapped_collection_fix is not None, \
         'No pcolormesh wrapping was done when it should have been.'
 
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(312, projection=ccrs.PlateCarree(-1.87499952))
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(3, 1, 2, projection=ccrs.PlateCarree(-1.87499952))
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(313, projection=ccrs.Robinson(-2))
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(3, 1, 3, projection=ccrs.Robinson(-2))
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
+    return fig
+
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_global_wrap3'], tolerance=1.42)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_global_wrap3.png',
+                               tolerance=1.42)
 def test_pcolormesh_set_array_with_mask():
     """Testing that set_array works with masked arrays properly."""
     nx, ny = 33, 17
@@ -437,11 +400,11 @@ def test_pcolormesh_set_array_with_mask():
     bad_data = np.ones(data.shape)
     # Start with the opposite mask and then swap back in the set_array call
     bad_data_mask = np.ma.array(bad_data, mask=~data.mask)
+    fig = plt.figure()
 
-    ax = plt.subplot(311, projection=ccrs.PlateCarree(-45))
-    c = plt.pcolormesh(xbnds, ybnds, bad_data,
-                       norm=norm, transform=ccrs.PlateCarree(),
-                       snap=False)
+    ax = fig.add_subplot(3, 1, 1, projection=ccrs.PlateCarree(-45))
+    c = ax.pcolormesh(xbnds, ybnds, bad_data,
+                      norm=norm, transform=ccrs.PlateCarree(), snap=False)
     c.set_array(data.ravel())
     assert c._wrapped_collection_fix is not None, \
         'No pcolormesh wrapping was done when it should have been.'
@@ -449,23 +412,24 @@ def test_pcolormesh_set_array_with_mask():
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(312, projection=ccrs.PlateCarree(-1.87499952))
-    c2 = plt.pcolormesh(xbnds, ybnds, bad_data_mask,
-                        norm=norm, transform=ccrs.PlateCarree(),
-                        snap=False)
+    ax = fig.add_subplot(3, 1, 2, projection=ccrs.PlateCarree(-1.87499952))
+    c2 = ax.pcolormesh(xbnds, ybnds, bad_data_mask,
+                       norm=norm, transform=ccrs.PlateCarree(), snap=False)
     c2.set_array(data.ravel())
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(313, projection=ccrs.Robinson(-2))
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(3, 1, 3, projection=ccrs.Robinson(-2))
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
+    return fig
+
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_global_wrap3'], tolerance=1.42)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_global_wrap3.png',
+                               tolerance=1.42)
 def test_pcolormesh_set_clim_with_mask():
     """Testing that set_clim works with masked arrays properly."""
     nx, ny = 33, 17
@@ -485,34 +449,36 @@ def test_pcolormesh_set_clim_with_mask():
     data = np.ma.masked_greater(data, 2.6)
 
     bad_initial_norm = plt.Normalize(-100, 100)
+    fig = plt.figure()
 
-    ax = plt.subplot(311, projection=ccrs.PlateCarree(-45))
-    c = plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                       norm=bad_initial_norm, snap=False)
+    ax = fig.add_subplot(3, 1, 1, projection=ccrs.PlateCarree(-45))
+    c = ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
+                      norm=bad_initial_norm, snap=False)
     assert c._wrapped_collection_fix is not None, \
         'No pcolormesh wrapping was done when it should have been.'
 
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(312, projection=ccrs.PlateCarree(-1.87499952))
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(3, 1, 2, projection=ccrs.PlateCarree(-1.87499952))
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
-    ax = plt.subplot(313, projection=ccrs.Robinson(-2))
-    plt.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(),
-                   snap=False)
+    ax = fig.add_subplot(3, 1, 3, projection=ccrs.Robinson(-2))
+    ax.pcolormesh(xbnds, ybnds, data, transform=ccrs.PlateCarree(), snap=False)
     ax.coastlines()
     ax.set_global()  # make sure everything is visible
 
     # Fix clims on c so that test passes
     c.set_clim(data.min(), data.max())
 
+    return fig
+
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_limited_area_wrap'], tolerance=1.82)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_limited_area_wrap.png',
+                               tolerance=1.82)
 def test_pcolormesh_limited_area_wrap():
     # make up some realistic data with bounds (such as data from the UM's North
     # Atlantic Europe model)
@@ -525,36 +491,37 @@ def test_pcolormesh_limited_area_wrap():
 
     rp = ccrs.RotatedPole(pole_longitude=177.5, pole_latitude=37.5)
 
-    plt.figure(figsize=(10, 6))
+    fig = plt.figure(figsize=(10, 6))
 
-    ax = plt.subplot(221, projection=ccrs.PlateCarree())
-    plt.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
-                   snap=False)
+    ax = fig.add_subplot(2, 2, 1, projection=ccrs.PlateCarree())
+    ax.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
+                  snap=False)
     ax.coastlines()
 
-    ax = plt.subplot(222, projection=ccrs.PlateCarree(180))
-    plt.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
-                   snap=False)
+    ax = fig.add_subplot(2, 2, 2, projection=ccrs.PlateCarree(180))
+    ax.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
+                  snap=False)
     ax.coastlines()
     ax.set_global()
 
     # draw the same plot, only more zoomed in, and using the 2d versions
     # of the coordinates (just to test that 1d and 2d are both suitably
     # being fixed)
-    ax = plt.subplot(223, projection=ccrs.PlateCarree())
-    plt.pcolormesh(x, y, data, transform=rp, cmap='Spectral',
-                   snap=False)
+    ax = fig.add_subplot(2, 2, 3, projection=ccrs.PlateCarree())
+    ax.pcolormesh(x, y, data, transform=rp, cmap='Spectral', snap=False)
     ax.coastlines()
     ax.set_extent([-70, 0, 0, 80])
 
-    ax = plt.subplot(224, projection=rp)
-    plt.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
-                   snap=False)
+    ax = fig.add_subplot(2, 2, 4, projection=rp)
+    ax.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
+                  snap=False)
     ax.coastlines()
 
+    return fig
+
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_single_column_wrap'], tolerance=0.7)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_single_column_wrap.png')
 def test_pcolormesh_single_column_wrap():
     # Check a wrapped mesh like test_pcolormesh_limited_area_wrap, but only use
     # a single column, which could break depending on how wrapping is
@@ -568,15 +535,17 @@ def test_pcolormesh_single_column_wrap():
 
     rp = ccrs.RotatedPole(pole_longitude=177.5, pole_latitude=37.5)
 
-    plt.figure(figsize=(10, 6))
+    fig = plt.figure(figsize=(10, 6))
 
-    ax = plt.subplot(111, projection=ccrs.PlateCarree(180))
+    ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree(180))
     # TODO: Remove snap when updating this image
-    plt.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
-                   snap=False)
+    ax.pcolormesh(xbnds, ybnds, data, transform=rp, cmap='Spectral',
+                  snap=False)
     ax.coastlines()
     ax.set_global()
 
+    return fig
+
 
 def test_pcolormesh_diagonal_wrap():
     # Check that a cell with the top edge on one side of the domain
@@ -606,7 +575,7 @@ def test_pcolormesh_nan_wrap():
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_goode_wrap'])
+@pytest.mark.mpl_image_compare(filename='pcolormesh_goode_wrap.png')
 def test_pcolormesh_goode_wrap():
     # global data on an Interrupted Goode Homolosine projection
     # shouldn't spill outside projection boundary
@@ -619,10 +588,11 @@ def test_pcolormesh_goode_wrap():
     ax.coastlines()
     # TODO: Remove snap when updating this image
     ax.pcolormesh(x, y, Z, transform=ccrs.PlateCarree(), snap=False)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_mercator_wrap'], tolerance=0.93)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_mercator_wrap.png')
 def test_pcolormesh_mercator_wrap():
     x = np.linspace(0, 360, 73)
     y = np.linspace(-87.5, 87.5, 36)
@@ -632,10 +602,11 @@ def test_pcolormesh_mercator_wrap():
     ax = plt.axes(projection=ccrs.Mercator())
     ax.coastlines()
     ax.pcolormesh(x, y, Z, transform=ccrs.PlateCarree(), snap=False)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['pcolormesh_mercator_wrap'], tolerance=0.93)
+@pytest.mark.mpl_image_compare(filename='pcolormesh_mercator_wrap.png')
 def test_pcolormesh_wrap_set_array():
     x = np.linspace(0, 360, 73)
     y = np.linspace(-87.5, 87.5, 36)
@@ -650,6 +621,7 @@ def test_pcolormesh_wrap_set_array():
                          transform=ccrs.PlateCarree(), snap=False)
     # Now update the plot with the set_array method
     coll.set_array(Z.ravel())
+    return ax.figure
 
 
 @pytest.mark.parametrize('shading, input_size, expected', [
@@ -678,7 +650,7 @@ def test_pcolormesh_shading(shading, input_size, expected):
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['quiver_plate_carree'])
+@pytest.mark.mpl_image_compare(filename='quiver_plate_carree.png')
 def test_quiver_plate_carree():
     x = np.arange(-60, 42.5, 2.5)
     y = np.arange(30, 72.5, 2.5)
@@ -687,21 +659,22 @@ def test_quiver_plate_carree():
     v = np.cos(2. * np.deg2rad(x2d))
     mag = (u**2 + v**2)**.5
     plot_extent = [-60, 40, 30, 70]
-    plt.figure(figsize=(6, 6))
+    fig = plt.figure(figsize=(6, 6))
     # plot on native projection
-    ax = plt.subplot(211, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 1, 1, projection=ccrs.PlateCarree())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines(resolution="110m")
     ax.quiver(x, y, u, v, mag)
     # plot on a different projection
-    ax = plt.subplot(212, projection=ccrs.NorthPolarStereo())
+    ax = fig.add_subplot(2, 1, 2, projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines()
     ax.quiver(x, y, u, v, mag, transform=ccrs.PlateCarree())
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['quiver_rotated_pole'])
+@pytest.mark.mpl_image_compare(filename='quiver_rotated_pole.png')
 def test_quiver_rotated_pole():
     nx, ny = 22, 36
     x = np.linspace(311.91998291, 391.11999512, nx, endpoint=True)
@@ -713,20 +686,21 @@ def test_quiver_rotated_pole():
     rp = ccrs.RotatedPole(pole_longitude=177.5, pole_latitude=37.5)
     plot_extent = [x[0], x[-1], y[0], y[-1]]
     # plot on native projection
-    plt.figure(figsize=(6, 6))
-    ax = plt.subplot(211, projection=rp)
+    fig = plt.figure(figsize=(6, 6))
+    ax = fig.add_subplot(2, 1, 1, projection=rp)
     ax.set_extent(plot_extent, crs=rp)
     ax.coastlines()
     ax.quiver(x, y, u, v, mag)
     # plot on different projection
-    ax = plt.subplot(212, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 1, 2, projection=ccrs.PlateCarree())
     ax.set_extent(plot_extent, crs=rp)
     ax.coastlines()
     ax.quiver(x, y, u, v, mag, transform=rp)
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['quiver_regrid'], tolerance=1.3)
+@pytest.mark.mpl_image_compare(filename='quiver_regrid.png')
 def test_quiver_regrid():
     x = np.arange(-60, 42.5, 2.5)
     y = np.arange(30, 72.5, 2.5)
@@ -735,16 +709,18 @@ def test_quiver_regrid():
     v = np.cos(2. * np.deg2rad(x2d))
     mag = (u**2 + v**2)**.5
     plot_extent = [-60, 40, 30, 70]
-    plt.figure(figsize=(6, 3))
-    ax = plt.axes(projection=ccrs.NorthPolarStereo())
+    fig = plt.figure(figsize=(6, 3))
+    ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines()
     ax.quiver(x, y, u, v, mag, transform=ccrs.PlateCarree(),
               regrid_shape=30)
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['quiver_regrid_with_extent'], tolerance=0.54)
+@pytest.mark.mpl_image_compare(filename='quiver_regrid_with_extent.png',
+                               tolerance=0.54)
 def test_quiver_regrid_with_extent():
     x = np.arange(-60, 42.5, 2.5)
     y = np.arange(30, 72.5, 2.5)
@@ -754,16 +730,17 @@ def test_quiver_regrid_with_extent():
     mag = (u**2 + v**2)**.5
     plot_extent = [-60, 40, 30, 70]
     target_extent = [-3e6, 2e6, -6e6, -2.5e6]
-    plt.figure(figsize=(6, 3))
-    ax = plt.axes(projection=ccrs.NorthPolarStereo())
+    fig = plt.figure(figsize=(6, 3))
+    ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines()
     ax.quiver(x, y, u, v, mag, transform=ccrs.PlateCarree(),
               regrid_shape=10, target_extent=target_extent)
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['barbs_plate_carree'])
+@pytest.mark.mpl_image_compare(filename='barbs_plate_carree.png')
 def test_barbs():
     x = np.arange(-60, 45, 5)
     y = np.arange(30, 75, 5)
@@ -771,21 +748,22 @@ def test_barbs():
     u = 40 * np.cos(np.deg2rad(y2d))
     v = 40 * np.cos(2. * np.deg2rad(x2d))
     plot_extent = [-60, 40, 30, 70]
-    plt.figure(figsize=(6, 6))
+    fig = plt.figure(figsize=(6, 6))
     # plot on native projection
-    ax = plt.subplot(211, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 1, 1, projection=ccrs.PlateCarree())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines(resolution="110m")
     ax.barbs(x, y, u, v, length=4, linewidth=.25)
     # plot on a different projection
-    ax = plt.subplot(212, projection=ccrs.NorthPolarStereo())
+    ax = fig.add_subplot(2, 1, 2, projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines(resolution="110m")
     ax.barbs(x, y, u, v, transform=ccrs.PlateCarree(), length=4, linewidth=.25)
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['barbs_regrid'])
+@pytest.mark.mpl_image_compare(filename='barbs_regrid.png')
 def test_barbs_regrid():
     x = np.arange(-60, 42.5, 2.5)
     y = np.arange(30, 72.5, 2.5)
@@ -794,16 +772,18 @@ def test_barbs_regrid():
     v = 40 * np.cos(2. * np.deg2rad(x2d))
     mag = (u**2 + v**2)**.5
     plot_extent = [-60, 40, 30, 70]
-    plt.figure(figsize=(6, 3))
-    ax = plt.axes(projection=ccrs.NorthPolarStereo())
+    fig = plt.figure(figsize=(6, 3))
+    ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines()
     ax.barbs(x, y, u, v, mag, transform=ccrs.PlateCarree(),
              length=4, linewidth=.4, regrid_shape=20)
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['barbs_regrid_with_extent'], tolerance=0.54)
+@pytest.mark.mpl_image_compare(filename='barbs_regrid_with_extent.png',
+                               tolerance=0.54)
 def test_barbs_regrid_with_extent():
     x = np.arange(-60, 42.5, 2.5)
     y = np.arange(30, 72.5, 2.5)
@@ -813,52 +793,54 @@ def test_barbs_regrid_with_extent():
     mag = (u**2 + v**2)**.5
     plot_extent = [-60, 40, 30, 70]
     target_extent = [-3e6, 2e6, -6e6, -2.5e6]
-    plt.figure(figsize=(6, 3))
-    ax = plt.axes(projection=ccrs.NorthPolarStereo())
+    fig = plt.figure(figsize=(6, 3))
+    ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines()
     ax.barbs(x, y, u, v, mag, transform=ccrs.PlateCarree(),
              length=4, linewidth=.25, regrid_shape=10,
              target_extent=target_extent)
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['barbs_1d'])
+@pytest.mark.mpl_image_compare(filename='barbs_1d.png')
 def test_barbs_1d():
     x = np.array([20., 30., -17., 15.])
     y = np.array([-1., 35., 11., 40.])
     u = np.array([23., -18., 2., -11.])
     v = np.array([5., -4., 19., 11.])
     plot_extent = [-21, 40, -5, 45]
-    plt.figure(figsize=(6, 5))
-    ax = plt.axes(projection=ccrs.PlateCarree())
+    fig = plt.figure(figsize=(6, 5))
+    ax = fig.add_subplot(projection=ccrs.PlateCarree())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines(resolution="110m")
     ax.barbs(x, y, u, v, transform=ccrs.PlateCarree(),
              length=8, linewidth=1, color='#7f7f7f')
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['barbs_1d_transformed'])
+@pytest.mark.mpl_image_compare(filename='barbs_1d_transformed.png')
 def test_barbs_1d_transformed():
     x = np.array([20., 30., -17., 15.])
     y = np.array([-1., 35., 11., 40.])
     u = np.array([23., -18., 2., -11.])
     v = np.array([5., -4., 19., 11.])
     plot_extent = [-20, 31, -5, 45]
-    plt.figure(figsize=(6, 5))
-    ax = plt.axes(projection=ccrs.NorthPolarStereo())
+    fig = plt.figure(figsize=(6, 5))
+    ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines()
     ax.barbs(x, y, u, v, transform=ccrs.PlateCarree(),
              length=8, linewidth=1, color='#7f7f7f')
+    return fig
 
 
 @pytest.mark.natural_earth
-@ImageTesting(
-    ['streamplot'], style='mpl20',
-    tolerance=(42 if MPL_VERSION.release[:2] < (3, 2) else
-               9.77 if MPL_VERSION.release[:2] < (3, 5) else 0.5))
+@pytest.mark.mpl_image_compare(
+    filename='streamplot.png', style='mpl20',
+    tolerance=9.77 if MPL_VERSION.release[:2] < (3, 5) else 0.5)
 def test_streamplot():
     x = np.arange(-60, 42.5, 2.5)
     y = np.arange(30, 72.5, 2.5)
@@ -867,9 +849,77 @@ def test_streamplot():
     v = np.cos(2. * np.deg2rad(x2d))
     mag = (u**2 + v**2)**.5
     plot_extent = [-60, 40, 30, 70]
-    plt.figure(figsize=(6, 3))
-    ax = plt.axes(projection=ccrs.NorthPolarStereo())
+    fig = plt.figure(figsize=(6, 3))
+    ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
     ax.set_extent(plot_extent, crs=ccrs.PlateCarree())
     ax.coastlines()
     ax.streamplot(x, y, u, v, transform=ccrs.PlateCarree(),
-                  density=(1.5, 2), color=mag, linewidth=2*mag)
+                  density=(1.5, 2), color=mag, linewidth=2 * mag)
+    return fig
+
+
+@pytest.mark.natural_earth
+@pytest.mark.mpl_image_compare()
+def test_annotate():
+    """ test a variety of annotate options on mulitple projections
+
+    Annotate defaults to coords passed as if they're in map projection space.
+    `transform` or `xycoords` & `textcoords` control the marker and text offset
+    through shared or independent projections or coordinates.
+    `transform` is a cartopy kwarg so expects a CRS,
+    `xycoords` and `textcoords` accept CRS or matplotlib args.
+
+    The various annotations below test a variety of the different combinations.
+    """
+    # use IGH to test annotations cross projection splits and map boundaries
+    map_projection = ccrs.InterruptedGoodeHomolosine()
+
+    fig = plt.figure(figsize=(10, 5))
+    ax = fig.add_subplot(1, 1, 1, projection=map_projection)
+    ax.set_global()
+    ax.coastlines()
+    arrowprops = {'facecolor': 'red',
+                  'arrowstyle': "-|>",
+                  'connectionstyle': "arc3,rad=-0.2",
+                  }
+    platecarree = ccrs.PlateCarree()
+    mpltransform = platecarree._as_mpl_transform(ax)
+
+    # Add annotation with xycoords as mpltransform as suggested here
+    # https://stackoverflow.com/questions/25416600/why-the-annotate-worked-unexpected-here-in-cartopy/25421922#25421922
+    ax.annotate('mpl xycoords', (-45, 43), xycoords=mpltransform,
+                size=5)
+
+    # Add annotation with xycoords as projection
+    ax.annotate('crs xycoords', (-75, 13), xycoords=platecarree,
+                size=5)
+
+    # set up coordinates in map projection space
+    map_coords = map_projection.transform_point(-175, -35, platecarree)
+    # Dont specifiy any args, default xycoords='data', transform=map projection
+    ax.annotate('default crs', map_coords, size=5)
+
+    # data in map projection using default transform, with
+    # text positioned in platecaree transform
+    ax.annotate('mixed crs transforms', map_coords, xycoords='data',
+                xytext=(-175, -55),
+                textcoords=platecarree,
+                size=5,
+                arrowprops=arrowprops,
+                )
+
+    # Add annotation with point and text via transform
+    ax.annotate('crs transform', (-75, -20), xytext=(0, -55),
+                transform=platecarree,
+                arrowprops=arrowprops,
+                )
+
+    # Add annotation with point via transform and text non transformed
+    ax.annotate('offset textcoords', (-149.8, 61.22), transform=platecarree,
+                xytext=(-35, 10), textcoords='offset points',
+                size=5,
+                ha='right',
+                arrowprops=arrowprops,
+                )
+
+    return fig
