@@ -15,16 +15,15 @@ import shapely.geometry as sgeom
 import cartopy.crs as ccrs
 import cartopy.mpl.patch as cpatch
 
-from cartopy.tests.mpl import ImageTesting
-
 
 # Note: Matplotlib is broken here
 # https://github.com/matplotlib/matplotlib/issues/15946
 @pytest.mark.natural_earth
-@ImageTesting(['poly_interiors'], tolerance=3.1)
+@pytest.mark.mpl_image_compare(filename='poly_interiors.png', tolerance=3.1)
 def test_polygon_interiors():
+    fig = plt.figure()
 
-    ax = plt.subplot(211, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 1, 1, projection=ccrs.PlateCarree())
     ax.coastlines()
     ax.set_global()
 
@@ -54,8 +53,8 @@ def test_polygon_interiors():
     ax.add_collection(collection)
 
     # test multiple interior polygons
-    ax = plt.subplot(212, projection=ccrs.PlateCarree(),
-                     xlim=[-5, 15], ylim=[-5, 15])
+    ax = fig.add_subplot(2, 1, 2, projection=ccrs.PlateCarree(),
+                         xlim=[-5, 15], ylim=[-5, 15])
     ax.coastlines(resolution="110m")
 
     exterior = np.array(sgeom.box(0, 0, 12, 12).exterior.coords)
@@ -71,9 +70,11 @@ def test_polygon_interiors():
                                  transform=ccrs.Geodetic(), zorder=10)
     ax.add_collection(collection)
 
+    return fig
+
 
 @pytest.mark.natural_earth
-@ImageTesting(['contour_with_interiors'])
+@pytest.mark.mpl_image_compare(filename='contour_with_interiors.png')
 def test_contour_interiors():
     # produces a polygon with multiple holes:
     nx, ny = 10, 10
@@ -81,16 +82,16 @@ def test_contour_interiors():
     lons, lats = np.meshgrid(np.linspace(-50, 50, nx),
                              np.linspace(-45, 45, ny))
     data = np.sin(np.sqrt(lons ** 2 + lats ** 2))
+    fig = plt.figure()
 
-    ax = plt.subplot(221, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 2, 1, projection=ccrs.PlateCarree())
     ax.set_global()
-    plt.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
+    ax.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
     ax.coastlines()
 
-    plt.subplot(222, projection=ccrs.Robinson())
-    ax = plt.gca()
+    ax = fig.add_subplot(2, 2, 2, projection=ccrs.Robinson())
     ax.set_global()
-    plt.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
+    ax.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
     ax.coastlines()
 
     # produces singular polygons (zero area polygons)
@@ -102,13 +103,14 @@ def test_contour_interiors():
     lats = np.arange(dim) + 30
     lons = np.arange(dim) - 20
 
-    ax = plt.subplot(223, projection=ccrs.PlateCarree())
+    ax = fig.add_subplot(2, 2, 3, projection=ccrs.PlateCarree())
     ax.set_global()
-    plt.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
+    ax.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
     ax.coastlines()
 
-    plt.subplot(224, projection=ccrs.Robinson())
-    ax = plt.gca()
+    ax = fig.add_subplot(2, 2, 4, projection=ccrs.Robinson())
     ax.set_global()
-    plt.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
+    ax.contourf(lons, lats, data, numlev, transform=ccrs.PlateCarree())
     ax.coastlines()
+
+    return fig
