@@ -8,27 +8,28 @@ import pytest
 
 import cartopy.crs as ccrs
 from cartopy.mpl.ticker import LongitudeFormatter, LatitudeFormatter
-from cartopy.tests.mpl import ImageTesting
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['xticks_no_transform'])
+@pytest.mark.mpl_image_compare(filename='xticks_no_transform.png')
 def test_set_xticks_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines('110m')
     ax.xaxis.set_major_formatter(LongitudeFormatter(degree_symbol=''))
     ax.set_xticks([-180, -90, 0, 90, 180])
     ax.set_xticks([-135, -45, 45, 135], minor=True)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['xticks_cylindrical'])
+@pytest.mark.mpl_image_compare(filename='xticks_cylindrical.png')
 def test_set_xticks_cylindrical():
     ax = plt.axes(projection=ccrs.Mercator(min_latitude=-85, max_latitude=85))
     ax.coastlines('110m')
     ax.xaxis.set_major_formatter(LongitudeFormatter(degree_symbol=''))
     ax.set_xticks([-180, -90, 0, 90, 180], crs=ccrs.PlateCarree())
     ax.set_xticks([-135, -45, 45, 135], minor=True, crs=ccrs.PlateCarree())
+    return ax.figure
 
 
 def test_set_xticks_non_cylindrical():
@@ -37,21 +38,21 @@ def test_set_xticks_non_cylindrical():
         ax.set_xticks([-180, -90, 0, 90, 180], crs=ccrs.Geodetic())
     with pytest.raises(RuntimeError):
         ax.set_xticks([-135, -45, 45, 135], minor=True, crs=ccrs.Geodetic())
-    plt.close()
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['yticks_no_transform'])
+@pytest.mark.mpl_image_compare(filename='yticks_no_transform.png')
 def test_set_yticks_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines('110m')
     ax.yaxis.set_major_formatter(LatitudeFormatter(degree_symbol=''))
     ax.set_yticks([-60, -30, 0, 30, 60])
     ax.set_yticks([-75, -45, -15, 15, 45, 75], minor=True)
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['yticks_cylindrical'])
+@pytest.mark.mpl_image_compare(filename='yticks_cylindrical.png')
 def test_set_yticks_cylindrical():
     ax = plt.axes(projection=ccrs.Mercator(min_latitude=-85, max_latitude=85))
     ax.coastlines('110m')
@@ -59,6 +60,7 @@ def test_set_yticks_cylindrical():
     ax.set_yticks([-60, -30, 0, 30, 60], crs=ccrs.PlateCarree())
     ax.set_yticks([-75, -45, -15, 15, 45, 75], minor=True,
                   crs=ccrs.PlateCarree())
+    return ax.figure
 
 
 def test_set_yticks_non_cylindrical():
@@ -68,11 +70,10 @@ def test_set_yticks_non_cylindrical():
     with pytest.raises(RuntimeError):
         ax.set_yticks([-75, -45, -15, 15, 45, 75], minor=True,
                       crs=ccrs.Geodetic())
-    plt.close()
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['xyticks'])
+@pytest.mark.mpl_image_compare(filename='xyticks.png')
 def test_set_xyticks():
     fig = plt.figure(figsize=(10, 10))
     projections = (ccrs.PlateCarree(),
@@ -87,3 +88,4 @@ def test_set_xyticks():
         p, q = prj.transform_point(x, y, ccrs.Geodetic())
         ax.set_xticks([p])
         ax.set_yticks([q])
+    return fig
