@@ -5,10 +5,8 @@
 # licensing details.
 
 import matplotlib.pyplot as plt
-from matplotlib.testing.decorators import cleanup
 import pytest
 
-from cartopy.tests.mpl import ImageTesting
 import cartopy.crs as ccrs
 from cartopy.io.ogc_clients import _OWSLIB_AVAILABLE
 
@@ -17,17 +15,17 @@ from cartopy.io.ogc_clients import _OWSLIB_AVAILABLE
 @pytest.mark.network
 @pytest.mark.skipif(not _OWSLIB_AVAILABLE, reason='OWSLib is unavailable.')
 @pytest.mark.xfail(raises=KeyError, reason='OWSLib WMTS support is broken.')
-@ImageTesting(['wmts'], tolerance=0)
+@pytest.mark.mpl_image_compare(filename='wmts.png', tolerance=0)
 def test_wmts():
     ax = plt.axes(projection=ccrs.PlateCarree())
     url = 'https://map1c.vis.earthdata.nasa.gov/wmts-geo/wmts.cgi'
     # Use a layer which doesn't change over time.
     ax.add_wmts(url, 'MODIS_Water_Mask')
+    return ax.figure
 
 
 @pytest.mark.network
 @pytest.mark.skipif(not _OWSLIB_AVAILABLE, reason='OWSLib is unavailable.')
-@cleanup
 def test_wms_tight_layout():
     ax = plt.axes(projection=ccrs.PlateCarree())
     url = 'http://vmap0.tiles.osgeo.org/wms/vmap0'
@@ -38,9 +36,10 @@ def test_wms_tight_layout():
 
 @pytest.mark.network
 @pytest.mark.skipif(not _OWSLIB_AVAILABLE, reason='OWSLib is unavailable.')
-@ImageTesting(['wms'], tolerance=0.02)
+@pytest.mark.mpl_image_compare(filename='wms.png', tolerance=0.02)
 def test_wms():
     ax = plt.axes(projection=ccrs.Orthographic())
     url = 'http://vmap0.tiles.osgeo.org/wms/vmap0'
     layer = 'basic'
     ax.add_wms(url, layer)
+    return ax.figure
