@@ -66,7 +66,7 @@ class TestCRS:
 
         # results obtained by streetmap.co.uk.
         lat, lon = np.array([50.462023, -3.478831], dtype=np.double)
-        east, north = np.array([295132.1,  63512.6], dtype=np.double)
+        east, north = np.array([295132.1, 63512.6], dtype=np.double)
 
         # note the handling of precision here...
         assert_almost_equal(osgb.transform_point(lon, lat, ll), [east, north],
@@ -89,7 +89,7 @@ class TestCRS:
     def test_epsg(self):
         uk = ccrs.epsg(27700)
         assert uk.epsg_code == 27700
-        assert_almost_equal(uk.x_limits, (-104009.357,  688806.007), decimal=3)
+        assert_almost_equal(uk.x_limits, (-104009.357, 688806.007), decimal=3)
         assert_almost_equal(uk.y_limits, (-8908.37, 1256558.45), decimal=2)
         assert_almost_equal(uk.threshold, 7928.15, decimal=2)
         self._check_osgb(uk)
@@ -173,6 +173,17 @@ class TestCRS:
         assert_arr_almost_eq(glon, soly)
         assert_arr_almost_eq(galt, solz)
 
+    def test_transform_points_180(self):
+        # Test that values less than -180 and more than 180
+        # get mapped to the -180, 180 interval
+        x = np.array([-190, 190])
+        y = np.array([0, 0])
+
+        proj = ccrs.PlateCarree()
+
+        res = proj.transform_points(x=x, y=y, src_crs=proj)
+        assert_array_equal(res[..., :2], [[170, 0], [-170, 0]])
+
     def test_globe(self):
         # Ensure the globe affects output.
         rugby_globe = ccrs.Globe(semimajor_axis=9000000,
@@ -303,8 +314,7 @@ def test_transform_points_outside_domain():
     crs = ccrs.Orthographic()
     result = crs.transform_points(ccrs.PlateCarree(),
                                   np.array([-120]), np.array([80]))
-    assert np.all(np.isnan(result[..., :2]))
-    assert result[..., -1] == 0
+    assert np.all(np.isnan(result))
     result = crs.transform_points(ccrs.PlateCarree(),
                                   np.array([-120]), np.array([80]),
                                   trap=True)
